@@ -47,9 +47,9 @@ for i, SnapNum in enumerate([10, 40]):
         plot.cax = grid.cbar_axes[i]
 
     # Actually redraws the plot.
-    p._setup_plots()
+    p.render()
 
-    # Modify the axes properties **after** p._setup_plots() so that they
+    # Modify the axes properties **after** p.render() so that they
     # are not overwritten.
     plot.axes.xaxis.set_minor_locator(plt.LogLocator(base=10.0, subs=[2.0, 5.0, 8.0]))
 
