@@ -17,11 +17,7 @@ import ewah_bool_utils
 from setuptools.command.build_ext import build_ext as _build_ext
 from setuptools.command.sdist import sdist as _sdist
 from setuptools.errors import CompileError, LinkError
-
-if sys.version_info >= (3, 9):
-    import importlib.resources as importlib_resources
-else:
-    import importlib_resources
+import importlib.resources as importlib_resources
 
 log = logging.getLogger("setupext")
 
@@ -204,12 +200,6 @@ def check_CPP14_flags(possible_compile_flags):
     )
     return []
 
-def get_ewah_bool_utils_path():
-    if sys.version_info >= (3, 9):
-        return os.path.abspath(importlib_resources.files("ewah_bool_utils"))
-    else:
-        from pkg_resources import resource_filename
-        return os.path.dirname(os.path.abspath(resource_filename("ewah_bool_utils", "ewah_bool_wrap.pxd")))
 
 def check_for_pyembree(std_libs):
     embree_libs = []
@@ -409,6 +399,17 @@ def create_build_ext(lib_exts, cythonize_aliases):
             self.include_dirs.append(numpy.get_include())
             self.include_dirs.append(ewah_bool_utils.get_include())
 
+            define_macros = [
+                ("NPY_NO_DEPRECATED_API", "NPY_1_7_API_VERSION"),
+                # keep in sync with runtime requirements (pyproject.toml)
+                ("NPY_TARGET_VERSION", "NPY_1_19_API_VERSION"),
+            ]
+
+            if self.define is None:
+                self.define = define_macros
+            else:
+                self.define.extend(define_macros)
+
         def build_extensions(self):
             self.check_extensions_list(self.extensions)
 
