@@ -35,7 +35,6 @@ from yt.fields.api import (
     derived_field,
     field_plugins,
 )
-from yt.frontends.api import _frontend_container
 from yt.funcs import (
     enable_plugins,
     get_memory_usage,
@@ -71,7 +70,7 @@ from yt.units import (
 from yt.units.unit_object import define_unit  # type: ignore
 from yt.utilities.logger import set_log_level, ytLogger as mylog
 
-frontends = _frontend_container()
+from yt import frontends
 
 import yt.visualization.volume_rendering.api as volume_rendering
 from yt.frontends.stream.api import hexahedral_connectivity
