@@ -1,13 +1,12 @@
 import copy
 from contextlib import contextmanager
-from typing import Dict
 
 from yt.fields.field_info_container import NullFunc, TranslationFunc
 from yt.funcs import mylog
 from yt.utilities.exceptions import YTIllDefinedFilter
 
 # One to one mapping
-filter_registry: Dict[str, "ParticleFilter"] = {}
+filter_registry: dict[str, "ParticleFilter"] = {}
 
 
 class DummyFieldInfo:
@@ -52,11 +51,11 @@ class ParticleFilter:
         return all((self.filtered_type, field) in field_list for field in self.requires)
 
     def missing(self, field_list):
-        return list(
+        return [
             (self.filtered_type, field)
             for field in self.requires
             if (self.filtered_type, field) not in field_list
-        )
+        ]
 
     def wrap_func(self, field_name, old_fi):
         new_fi = copy.copy(old_fi)
