@@ -274,8 +274,8 @@ class ProfileND(ParallelAnalysisInterface):
                 fname = self.field_map.get(field[1], None)
                 if fname != field:
                     raise KeyError(
-                        "Asked for field '{}' but only have data for "
-                        "fields '{}'".format(field, list(self.field_data.keys()))
+                        f"Asked for field '{field}' but only have data for "
+                        f"fields '{list(self.field_data.keys())}'"
                     )
             elif isinstance(field, DerivedField):
                 fname = self.field_map.get(field.name[1], None)
@@ -562,7 +562,7 @@ class Profile1D(ProfileND):
             fields = self.data_source._determine_fields(fields)
         return idxs, masked, fields
 
-    def to_dataframe(self, fields=None, only_used=False):
+    def to_dataframe(self, fields=None, only_used=False, include_std=False):
         r"""Export a profile object to a pandas DataFrame.
 
         This function will take a data object and construct from it and
@@ -577,8 +577,13 @@ class Profile1D(ProfileND):
             profile, along with the bin field, will be exported.
         only_used : boolean, default False
             If True, only the bins which have data will be exported. If False,
-            all of the bins will be exported, but the elements for those bins
+            all the bins will be exported, but the elements for those bins
             in the data arrays will be filled with NaNs.
+        include_std : boolean, optional
+            If True, include the standard deviation of the profile
+            in the pandas DataFrame. It will appear in the table as the
+            field name with "_stddev" appended, e.g. "velocity_x_stddev".
+            Default: False
 
         Returns
         -------
@@ -600,6 +605,8 @@ class Profile1D(ProfileND):
         pdata = {self.x_field[-1]: self.x[idxs]}
         for field in fields:
             pdata[field[-1]] = self[field][idxs]
+            if include_std:
+                pdata[f"{field[-1]}_stddev"] = self.standard_deviation[field][idxs]
         df = pd.DataFrame(pdata)
         if masked:
             mask = np.zeros(df.shape, dtype="bool")
@@ -607,7 +614,7 @@ class Profile1D(ProfileND):
             df.mask(mask, inplace=True)
         return df
 
-    def to_astropy_table(self, fields=None, only_used=False):
+    def to_astropy_table(self, fields=None, only_used=False, include_std=False):
         """
         Export the profile data to a :class:`~astropy.table.table.QTable`,
         which is a Table object which is unit-aware. The QTable can then
@@ -627,10 +634,15 @@ class Profile1D(ProfileND):
             to the QTable as rows. If False, all bins are
             copied, but the bins which are not used are masked.
             Default: False
+        include_std : boolean, optional
+            If True, include the standard deviation of the profile
+            in the AstroPy QTable. It will appear in the table as the
+            field name with "_stddev" appended, e.g. "velocity_x_stddev".
+            Default: False
 
         Returns
         -------
-        df : :class:`~astropy.table.QTable`
+        qt : :class:`~astropy.table.QTable`
             The data contained in the profile.
 
         Examples
@@ -653,6 +665,12 @@ class Profile1D(ProfileND):
             qt[field[-1]] = self[field][idxs].to_astropy()
             if masked:
                 qt[field[-1]].mask = self.used
+            if include_std:
+                qt[f"{field[-1]}_stddev"] = self.standard_deviation[field][
+                    idxs
+                ].to_astropy()
+                if masked:
+                    qt[f"{field[-1]}_stddev"].mask = self.used
         return qt
 
 
@@ -885,7 +903,6 @@ class ParticleProfile(Profile2D):
         weight_field=None,
         deposition="ngp",
     ):
-
         x_field = data_source._determine_fields(x_field)[0]
         y_field = data_source._determine_fields(y_field)[0]
 
@@ -1378,7 +1395,7 @@ def create_profile(
 
             if isinstance(field_ex[0], tuple):
                 field_ex = [data_source.ds.quan(*f) for f in field_ex]
-            if any([exi is None for exi in field_ex]):
+            if any(exi is None for exi in field_ex):
                 try:
                     ds_extrema = data_source.quantities.extrema(bin_field)
                 except AttributeError:
@@ -1445,7 +1462,7 @@ def create_profile(
         if mi <= 0 and l:
             raise YTIllDefinedBounds(mi, ma)
         args += [f, n, mi, ma, l]
-    kwargs = dict(weight_field=weight_field)
+    kwargs = {"weight_field": weight_field}
     if cls is ParticleProfile:
         kwargs["deposition"] = deposition
     if override_bins is not None:
@@ -1455,7 +1472,7 @@ def create_profile(
     obj.accumulation = accumulation
     obj.fractional = fractional
     if fields is not None:
-        obj.add_fields([field for field in fields])
+        obj.add_fields(list(fields))
     for field in fields:
         if fractional:
             obj.field_data[field] /= obj.field_data[field].sum()
@@ -1474,7 +1491,10 @@ def create_profile(
             if weight_field is None:
                 temp = temp.cumsum(axis=0)
             else:
-                temp = (temp * temp_weight).cumsum(axis=0) / temp_weight.cumsum(axis=0)
+                # avoid 0-division warnings by nan-masking
+                _denom = temp_weight.cumsum(axis=0)
+                _denom[_denom == 0.0] = np.nan
+                temp = (temp * temp_weight).cumsum(axis=0) / _denom
             if acc < 0:
                 temp = temp[::-1]
                 if weight_field is not None:
