@@ -1,11 +1,13 @@
 import abc
 import itertools
+import sys
 import uuid
 from collections import defaultdict
 from contextlib import contextmanager
 
 import numpy as np
 from more_itertools import always_iterable
+from unyt import unyt_array
 from unyt.exceptions import UnitConversionError, UnitParseError
 
 import yt.geometry
@@ -14,6 +16,7 @@ from yt.data_objects.derived_quantities import DerivedQuantityCollection
 from yt.data_objects.field_data import YTFieldData
 from yt.fields.field_exceptions import NeedsGridType
 from yt.funcs import fix_axis, is_sequence, iter_fields, validate_width_tuple
+from yt.geometry.api import Geometry
 from yt.geometry.selection_routines import compose_selector
 from yt.units import YTArray
 from yt.utilities.exceptions import (
@@ -31,6 +34,11 @@ from yt.utilities.parallel_tools.parallel_analysis_interface import (
     ParallelAnalysisInterface,
 )
 
+if sys.version_info >= (3, 11):
+    from typing import assert_never
+else:
+    from typing_extensions import assert_never
+
 
 class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface, abc.ABC):
     _locked = False
@@ -107,7 +115,7 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface, abc.ABC):
             if inspected >= len(fields_to_get):
                 break
             inspected += 1
-            fi = self.ds._get_field_info(*field)
+            fi = self.ds._get_field_info(field)
             fd = self.ds.field_dependencies.get(
                 field, None
             ) or self.ds.field_dependencies.get(field[1], None)
@@ -165,7 +173,7 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface, abc.ABC):
         for field in self._determine_fields(fields):
             if field in self.field_data:
                 continue
-            finfo = self.ds._get_field_info(*field)
+            finfo = self.ds._get_field_info(field)
             try:
                 finfo.check_available(self)
             except NeedsGridType:
@@ -183,13 +191,13 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface, abc.ABC):
         # We now split up into readers for the types of fields
         fluids, particles = [], []
         finfos = {}
-        for ftype, fname in fields_to_get:
-            finfo = self.ds._get_field_info(ftype, fname)
-            finfos[ftype, fname] = finfo
+        for field_key in fields_to_get:
+            finfo = self.ds._get_field_info(field_key)
+            finfos[field_key] = finfo
             if finfo.sampling_type == "particle":
-                particles.append((ftype, fname))
-            elif (ftype, fname) not in fluids:
-                fluids.append((ftype, fname))
+                particles.append(field_key)
+            elif field_key not in fluids:
+                fluids.append(field_key)
         # The _read method will figure out which fields it needs to get from
         # disk, and return a dict of those fields along with the fields that
         # need to be generated.
@@ -216,6 +224,17 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface, abc.ABC):
 
     def _generate_fields(self, fields_to_generate):
         index = 0
+
+        def dimensions_compare_equal(a, b, /) -> bool:
+            if a == b:
+                return True
+            try:
+                if (a == 1 and b.is_dimensionless) or (a.is_dimensionless and b == 1):
+                    return True
+            except AttributeError:
+                return False
+            return False
+
         with self._field_lock():
             # At this point, we assume that any fields that are necessary to
             # *generate* a field are in fact already available to us.  Note
@@ -228,7 +247,7 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface, abc.ABC):
                 index += 1
                 if field in self.field_data:
                     continue
-                fi = self.ds._get_field_info(*field)
+                fi = self.ds._get_field_info(field)
                 try:
                     fd = self._generate_field(field)
                     if hasattr(fd, "units"):
@@ -253,11 +272,11 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface, abc.ABC):
                         if fi.dimensions is None:
                             mylog.warning(
                                 "Field %s was added without specifying units or dimensions, "
-                                "auto setting units to %s",
+                                "auto setting units to %r",
                                 fi.name,
-                                sunits,
+                                sunits or "dimensionless",
                             )
-                        elif fi.dimensions != dimensions:
+                        elif not dimensions_compare_equal(fi.dimensions, dimensions):
                             raise YTDimensionalityError(fi.dimensions, dimensions)
                         fi.units = sunits
                         fi.dimensions = dimensions
@@ -590,8 +609,8 @@ class YTSelectionContainer2D(YTSelectionContainer):
         >>> write_image(np.log10(frb[("gas", "density")]), "density_100kpc.png")
         """
 
-        if (self.ds.geometry == "cylindrical" and self.axis == 1) or (
-            self.ds.geometry == "polar" and self.axis == 2
+        if (self.ds.geometry is Geometry.CYLINDRICAL and self.axis == 1) or (
+            self.ds.geometry is Geometry.POLAR and self.axis == 2
         ):
             if center is not None and center != (0.0, 0.0):
                 raise NotImplementedError(
@@ -1304,7 +1323,6 @@ class YTSelectionContainer3D(YTSelectionContainer):
     def _calculate_flux_in_grid(
         self, grid, mask, field, value, field_x, field_y, field_z, fluxing_field=None
     ):
-
         vc_fields = [field, field_x, field_y, field_z]
         if fluxing_field is not None:
             vc_fields.append(fluxing_field)
@@ -1379,18 +1397,29 @@ class YTSelectionContainer3D(YTSelectionContainer):
         """
         return self.ds.domain_left_edge, self.ds.domain_right_edge
 
-    def get_bbox(self):
+    def get_bbox(self) -> tuple[unyt_array, unyt_array]:
         """
         Return the bounding box for this data container.
         """
-        if self.ds.geometry != "cartesian":
+        geometry: Geometry = self.ds.geometry
+        if geometry is Geometry.CARTESIAN:
+            le, re = self._get_bbox()
+            le.convert_to_units("code_length")
+            re.convert_to_units("code_length")
+            return le, re
+        elif (
+            geometry is Geometry.CYLINDRICAL
+            or geometry is Geometry.POLAR
+            or geometry is Geometry.SPHERICAL
+            or geometry is Geometry.GEOGRAPHIC
+            or geometry is Geometry.INTERNAL_GEOGRAPHIC
+            or geometry is Geometry.SPECTRAL_CUBE
+        ):
             raise NotImplementedError(
-                "get_bbox is currently only implemented for cartesian geometries!"
+                f"get_bbox is currently not implemented for {geometry=}!"
             )
-        le, re = self._get_bbox()
-        le.convert_to_units("code_length")
-        re.convert_to_units("code_length")
-        return le, re
+        else:
+            assert_never(geometry)
 
     def volume(self):
         """
