@@ -9,21 +9,11 @@ import time
 import warnings
 import weakref
 from collections import defaultdict
+from collections.abc import MutableMapping
 from functools import cached_property
 from importlib.util import find_spec
 from stat import ST_CTIME
-from typing import (
-    Any,
-    DefaultDict,
-    Dict,
-    List,
-    Literal,
-    Optional,
-    Set,
-    Tuple,
-    Type,
-    Union,
-)
+from typing import Any, Literal, Optional, Union
 
 import numpy as np
 import unyt as un
@@ -89,11 +79,6 @@ if sys.version_info >= (3, 11):
 else:
     from typing_extensions import assert_never
 
-if sys.version_info >= (3, 9):
-    from collections.abc import MutableMapping
-else:
-    from typing import MutableMapping
-
 
 # We want to support the movie format in the future.
 # When such a thing comes to pass, I'll move all the stuff that is constant up
@@ -131,26 +116,29 @@ class MutableAttribute:
 
     def __init__(self, display_array=False):
         self.data = weakref.WeakKeyDictionary()
-        self.display_array = display_array
+        # We can assume that ipywidgets will not be *added* to the system
+        # during the course of execution, and if it is, we will not wrap the
+        # array.
+        if display_array and find_spec("ipywidgets") is not None:
+            self.display_array = True
+        else:
+            self.display_array = False
 
     def __get__(self, instance, owner):
-        if not instance:
-            return None
-        ret = self.data.get(instance, None)
-        try:
-            ret = ret.copy()
-        except AttributeError:
-            pass
-        if self.display_array and find_spec("ipywidgets") is not None:
-            try:
-                ret._ipython_display_ = functools.partial(_wrap_display_ytarray, ret)
-            # This will error out if the items have yet to be turned into
-            # YTArrays, in which case we just let it go.
-            except AttributeError:
-                pass
-        return ret
+        return self.data.get(instance, None)
 
     def __set__(self, instance, value):
+        if self.display_array:
+            try:
+                value._ipython_display_ = functools.partial(
+                    _wrap_display_ytarray, value
+                )
+            except AttributeError:
+                # If they have slots, we can't assign a new item.  So, let's catch
+                # the error!
+                pass
+        if isinstance(value, np.ndarray):
+            value.flags.writeable = False
         self.data[instance] = value
 
 
@@ -170,28 +158,29 @@ def requires_index(attr_name):
 
 
 class Dataset(abc.ABC):
+    _load_requirements: list[str] = []
     default_fluid_type = "gas"
     default_field = ("gas", "density")
-    fluid_types: Tuple[FieldType, ...] = ("gas", "deposit", "index")
-    particle_types: Tuple[ParticleType, ...] = ("io",)  # By default we have an 'all'
-    particle_types_raw: Optional[Tuple[ParticleType, ...]] = ("io",)
+    fluid_types: tuple[FieldType, ...] = ("gas", "deposit", "index")
+    particle_types: tuple[ParticleType, ...] = ("io",)  # By default we have an 'all'
+    particle_types_raw: Optional[tuple[ParticleType, ...]] = ("io",)
     geometry: Geometry = Geometry.CARTESIAN
     coordinates = None
     storage_filename = None
-    particle_unions: Optional[Dict[ParticleType, ParticleUnion]] = None
-    known_filters: Optional[Dict[ParticleType, ParticleFilter]] = None
-    _index_class: Type[Index]
-    field_units: Optional[Dict[AnyFieldKey, Unit]] = None
+    particle_unions: Optional[dict[ParticleType, ParticleUnion]] = None
+    known_filters: Optional[dict[ParticleType, ParticleFilter]] = None
+    _index_class: type[Index]
+    field_units: Optional[dict[AnyFieldKey, Unit]] = None
     derived_field_list = requires_index("derived_field_list")
     fields = requires_index("fields")
-    conversion_factors: Optional[Dict[str, float]] = None
+    conversion_factors: Optional[dict[str, float]] = None
     # _instantiated represents an instantiation time (since Epoch)
     # the default is a place holder sentinel, falsy value
     _instantiated: float = 0
     _particle_type_counts = None
     _proj_type = "quad_proj"
     _ionization_label_format = "roman_numeral"
-    _determined_fields: Optional[Dict[str, List[FieldKey]]] = None
+    _determined_fields: Optional[dict[str, list[FieldKey]]] = None
     fields_detected = False
 
     # these are set in self._parse_parameter_file()
@@ -247,7 +236,7 @@ class Dataset(abc.ABC):
         self,
         filename: str,
         dataset_type: Optional[str] = None,
-        units_override: Optional[Dict[str, str]] = None,
+        units_override: Optional[dict[str, str]] = None,
         # valid unit_system values include all keys from unyt.unit_systems.unit_systems_registry + "code"
         unit_system: Literal[
             "cgs",
@@ -275,7 +264,7 @@ class Dataset(abc.ABC):
             return
         self.dataset_type = dataset_type
         self.conversion_factors = {}
-        self.parameters: Dict[str, Any] = {}
+        self.parameters: dict[str, Any] = {}
         self.region_expression = self.r = RegionExpression(self)
         self.known_filters = self.known_filters or {}
         self.particle_unions = self.particle_unions or {}
@@ -349,7 +338,8 @@ class Dataset(abc.ABC):
             "the Dataset.fullpath attribute is now aliased to Dataset.directory, "
             "and all path attributes are now absolute. "
             "Please use the directory attribute instead",
-            since="4.1.0",
+            stacklevel=3,
+            since="4.1",
         )
         return self.directory
 
@@ -385,10 +375,17 @@ class Dataset(abc.ABC):
             raise TypeError("force_periodicity expected a boolean.")
         self._force_periodicity = val
 
+    @classmethod
+    def _missing_load_requirements(cls) -> list[str]:
+        # return a list of optional dependencies that are
+        # needed for the present class to function, but currently missing.
+        # returning an empty list means that all requirements are met
+        return [name for name in cls._load_requirements if not find_spec(name)]
+
     # abstract methods require implementation in subclasses
     @classmethod
     @abc.abstractmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         # A heuristic test to determine if the data format can be interpreted
         # with the present frontend
         return False
@@ -722,10 +719,8 @@ class Dataset(abc.ABC):
                 )
         else:
             raise ValueError(
-                "{} not a recognized format_property. Available "
-                "properties are: {}".format(
-                    format_property, list(available_formats.keys())
-                )
+                f"{format_property} not a recognized format_property. Available "
+                f"properties are: {list(available_formats.keys())}"
             )
 
     def setup_deprecated_fields(self):
@@ -744,7 +739,7 @@ class Dataset(abc.ABC):
     def _setup_coordinate_handler(self, axis_order: Optional[AxisOrder]) -> None:
         # backward compatibility layer:
         # turning off type-checker on a per-line basis
-        cls: Type[CoordinateHandler]
+        cls: type[CoordinateHandler]
 
         if isinstance(self.geometry, tuple):  # type: ignore [unreachable]
             issue_deprecation_warning(  # type: ignore [unreachable]
@@ -773,7 +768,7 @@ class Dataset(abc.ABC):
             )
             cls = self.geometry  # type: ignore [assignment]
 
-        if type(self.geometry) is str:
+        if type(self.geometry) is str:  # noqa: E721
             issue_deprecation_warning(
                 f"Dataset object {self} has a raw string for its geometry attribute. "
                 "In yt>=4.2, a yt.geometry.geometry_enum.Geometry member is expected instead. "
@@ -966,7 +961,7 @@ class Dataset(abc.ABC):
             # https://github.com/yt-project/yt/issues/3381
             return field_info
 
-        def _are_ambiguous(candidates: List[FieldKey]) -> bool:
+        def _are_ambiguous(candidates: list[FieldKey]) -> bool:
             if len(candidates) < 2:
                 return False
 
@@ -989,7 +984,7 @@ class Dataset(abc.ABC):
             elif all(ft in self.particle_types for ft in ftypes):
                 ptypes = ftypes
 
-                sub_types_list: List[Set[str]] = []
+                sub_types_list: list[set[str]] = []
                 for pt in ptypes:
                     if pt in self.particle_types_raw:
                         sub_types_list.append({pt})
@@ -1019,7 +1014,7 @@ class Dataset(abc.ABC):
         self,
         field: Union[FieldKey, ImplicitFieldKey, DerivedField],
         /,
-    ) -> Tuple[DerivedField, List[FieldKey]]:
+    ) -> tuple[DerivedField, list[FieldKey]]:
         self.index
 
         ftype: str
@@ -1034,7 +1029,7 @@ class Dataset(abc.ABC):
             raise YTFieldNotParseable(field)
 
         if ftype == "unknown":
-            candidates: List[FieldKey] = [
+            candidates: list[FieldKey] = [
                 (ft, fn) for ft, fn in self.field_info if fn == fname
             ]
 
@@ -1290,7 +1285,7 @@ class Dataset(abc.ABC):
         # dimensions as amperes.
         mks_system = False
         mag_unit: Optional[unyt_quantity] = getattr(self, "magnetic_unit", None)
-        mag_dims: Optional[Set[Symbol]]
+        mag_dims: Optional[set[Symbol]]
         if mag_unit is not None:
             mag_dims = mag_unit.units.dimensions.free_symbols
         else:
@@ -2068,7 +2063,7 @@ class ParticleFile:
 
     start: Optional[int] = None
     end: Optional[int] = None
-    total_particles: Optional[DefaultDict[str, int]] = None
+    total_particles: Optional[defaultdict[str, int]] = None
 
     def __init__(self, ds, io, filename, file_id, range=None):
         self.ds = ds
