@@ -1,7 +1,9 @@
 import os
 import tempfile
 
-from yt.testing import assert_equal, fake_random_ds
+from numpy.testing import assert_equal
+
+from yt.testing import fake_random_ds
 from yt.units.unit_object import Unit
 
 
@@ -40,10 +42,10 @@ def test_cutting_plane():
         for width in [(1.0, "unitary"), 1.0, ds.quan(0.5, "code_length")]:
             frb = cut.to_frb(width, 64)
             for cut_field in [("index", "ones"), ("gas", "density")]:
-                fi = ds._get_field_info("unknown", cut_field)
+                fi = ds._get_field_info(cut_field)
                 data = frb[cut_field]
                 assert_equal(data.info["data_source"], cut.__str__())
-                assert_equal(data.info["axis"], 4)
+                assert_equal(data.info["axis"], None)
                 assert_equal(data.info["field"], str(cut_field))
                 assert_equal(data.units, Unit(fi.units))
                 assert_equal(data.info["xlim"], frb.bounds[:2])
