@@ -1,6 +1,7 @@
 import numpy as np
+from numpy.testing import assert_array_less
 
-from yt.testing import assert_array_less, fake_random_ds
+from yt.testing import fake_random_ds
 
 
 def setup():
@@ -24,7 +25,7 @@ def test_ellipsoid():
         np.array([0.1, 0.2, 0.3]),
         np.array([0.8, 0.8, 0.8]),
     ]
-    np.random.seed(int(0x4D3D3D3))
+    np.random.seed(0x4D3D3D3)
     for nprocs in [1, 2, 4, 8]:
         ds = fake_random_ds(64, nprocs=nprocs)
         DW = ds.domain_right_edge - ds.domain_left_edge
@@ -35,7 +36,7 @@ def test_ellipsoid():
         ABC[:, 0] = 0.1
         for i in range(12):
             for c in cs:
-                A, B, C = reversed(sorted(ABC[:, i]))
+                A, B, C = sorted(ABC[:, i], reverse=True)
                 A = max(A, min_dx[0])
                 B = max(B, min_dx[1])
                 C = max(C, min_dx[2])
