@@ -23,7 +23,7 @@ def teardown_func(fns):
             pass
 
 
-@mock.patch("yt.visualization._mpl_imports.FigureCanvasAgg.print_figure")
+@mock.patch("matplotlib.backends.backend_agg.FigureCanvasAgg.print_figure")
 def test_slice(pf):
     fns = []
     grid_eps = np.finfo(np.float64).eps
