@@ -1,7 +1,9 @@
 import numpy as np
+from numpy.testing import assert_almost_equal, assert_equal
 
-from yt import SlicePlot
-from yt.testing import assert_equal, fake_sph_grid_ds, fake_sph_orientation_ds
+from yt import SlicePlot, add_particle_filter
+from yt.loaders import load
+from yt.testing import fake_sph_grid_ds, fake_sph_orientation_ds, requires_file
 
 
 def test_point():
@@ -347,3 +349,29 @@ def test_covering_grid_gather():
     cg_dens = cg[field].to("g*cm**-3").d
 
     assert_equal(ag_dens, cg_dens)
+
+
+@requires_file("TNGHalo/halo_59.hdf5")
+def test_covering_grid_derived_fields():
+    def hot_gas(pfilter, data):
+        return data[pfilter.filtered_type, "temperature"] > 1.0e6
+
+    add_particle_filter(
+        "hot_gas",
+        function=hot_gas,
+        filtered_type="gas",
+        requires=["temperature"],
+    )
+    bbox = [[40669.34, 56669.34], [45984.04, 61984.04], [54114.9, 70114.9]]
+    ds = load("TNGHalo/halo_59.hdf5", bounding_box=bbox)
+    ds.add_particle_filter("hot_gas")
+    w = ds.quan(0.2, "Mpc")
+    le = ds.domain_center - 0.5 * w
+    re = ds.domain_center + 0.5 * w
+    g = ds.r[le[0] : re[0] : 128j, le[1] : re[1] : 128j, le[2] : re[2] : 128j]
+    T1 = g["gas", "temperature"].to("keV", "thermal")
+    T2 = g["gas", "kT"]
+    assert_almost_equal(T1, T2)
+    T3 = g["hot_gas", "temperature"].to("keV", "thermal")
+    T4 = g["hot_gas", "kT"]
+    assert_almost_equal(T3, T4)
