@@ -5,7 +5,7 @@ import os
 import weakref
 from abc import ABC, abstractmethod
 from functools import wraps
-from typing import Optional, Type
+from typing import Optional
 
 import numpy as np
 from more_itertools import always_iterable
@@ -146,7 +146,7 @@ class DatasetSeries:
     # this annotation should really be Optional[Type[Dataset]]
     # but we cannot import the yt.data_objects.static_output.Dataset
     # class here without creating a circular import for now
-    _dataset_cls: Optional[Type] = None
+    _dataset_cls: Optional[type] = None
 
     def __init_subclass__(cls, *args, **kwargs):
         super().__init_subclass__(*args, **kwargs)
@@ -417,7 +417,7 @@ class DatasetSeries:
         ... ]
         >>> ds = load(my_fns[0])
         >>> init_sphere = ds.sphere(ds.domain_center, (0.5, "unitary"))
-        >>> indices = init_sphere[("all", "particle_index")].astype("int")
+        >>> indices = init_sphere[("all", "particle_index")].astype("int64")
         >>> ts = DatasetSeries(my_fns)
         >>> trajs = ts.particle_trajectories(indices, fields=fields)
         >>> for t in trajs:
