@@ -1,6 +1,7 @@
 import contextlib
 import inspect
 import re
+from collections.abc import Iterable
 from typing import Optional, Union
 
 from more_itertools import always_iterable
@@ -323,7 +324,8 @@ class DerivedField:
     def alias_field(self) -> bool:
         issue_deprecation_warning(
             "DerivedField.alias_field is a deprecated equivalent to DerivedField.is_alias ",
-            since="4.1.0",
+            stacklevel=3,
+            since="4.1",
         )
         return self.is_alias
 
@@ -388,6 +390,16 @@ class DerivedField:
             "17": "XVIII",
             "18": "XIX",
             "19": "XX",
+            "20": "XXI",
+            "21": "XXII",
+            "22": "XXIII",
+            "23": "XXIV",
+            "24": "XXV",
+            "25": "XXVI",
+            "26": "XXVII",
+            "27": "XXVIII",
+            "28": "XXIX",
+            "29": "XXX",
         }
 
         # first look for charge to decide if it is an ion
@@ -488,17 +500,37 @@ class DerivedField:
 
 
 class FieldValidator:
-    pass
+    """
+    Base class for FieldValidator objects. Available subclasses include:
+    """
+
+    def __init_subclass__(cls, **kwargs):
+        # add the new subclass to the list of subclasses in the docstring
+        class_str = f":class:`{cls.__name__}`"
+        if ":class:" in FieldValidator.__doc__:
+            class_str = ", " + class_str
+        FieldValidator.__doc__ += class_str
 
 
 class ValidateParameter(FieldValidator):
-    def __init__(self, parameters, parameter_values=None):
-        """
-        This validator ensures that the dataset has a given parameter.
+    """
+    A :class:`FieldValidator` that ensures the dataset has a given parameter.
 
-        If *parameter_values* is supplied, this will also ensure that the field
+    Parameters
+    ----------
+    parameters: str, iterable[str]
+        a single parameter or list of parameters to require
+    parameter_values: dict
+        If *parameter_values* is supplied, this dict should map from field
+        parameter to a value or list of values. It will ensure that the field
         is available for all permutations of the field parameter.
-        """
+    """
+
+    def __init__(
+        self,
+        parameters: Union[str, Iterable[str]],
+        parameter_values: Optional[dict] = None,
+    ):
         FieldValidator.__init__(self)
         self.parameters = list(always_iterable(parameters))
         self.parameter_values = parameter_values
@@ -514,11 +546,17 @@ class ValidateParameter(FieldValidator):
 
 
 class ValidateDataField(FieldValidator):
+    """
+    A :class:`FieldValidator` that ensures the output file has a given data field stored
+    in it.
+
+    Parameters
+    ----------
+    field: str, tuple[str, str], or any iterable of the previous types.
+        the field or fields to require
+    """
+
     def __init__(self, field):
-        """
-        This validator ensures that the output file has a given data field stored
-        in it.
-        """
         FieldValidator.__init__(self)
         self.fields = list(iter_fields(field))
 
@@ -535,29 +573,42 @@ class ValidateDataField(FieldValidator):
 
 
 class ValidateProperty(FieldValidator):
-    def __init__(self, prop):
-        """
-        This validator ensures that the data object has a given python attribute.
-        """
+    """
+    A :class:`FieldValidator` that ensures the data object has a given python attribute.
+
+    Parameters
+    ----------
+    prop: str, iterable[str]
+        the required property or properties to require
+    """
+
+    def __init__(self, prop: Union[str, Iterable[str]]):
         FieldValidator.__init__(self)
         self.prop = list(always_iterable(prop))
 
     def __call__(self, data):
-        doesnt_have = []
-        for p in self.prop:
-            if not hasattr(data, p):
-                doesnt_have.append(p)
+        doesnt_have = [p for p in self.prop if not hasattr(data, p)]
         if len(doesnt_have) > 0:
             raise NeedsProperty(doesnt_have)
         return True
 
 
 class ValidateSpatial(FieldValidator):
-    def __init__(self, ghost_zones=0, fields=None):
-        """
-        This validator ensures that the data handed to the field is of spatial
-        nature -- that is to say, 3-D.
-        """
+    """
+    A :class:`FieldValidator` that ensures the data handed to the field is of spatial
+    nature -- that is to say, 3-D.
+
+    Parameters
+    ----------
+    ghost_zones: int
+        If supplied, will validate that the number of ghost zones required
+        for the field is <= the available ghost zones. Default is 0.
+    fields: Optional str, tuple[str, str], or any iterable of the previous types.
+        The field or fields to validate.
+
+    """
+
+    def __init__(self, ghost_zones: Optional[int] = 0, fields=None):
         FieldValidator.__init__(self)
         self.ghost_zones = ghost_zones
         self.fields = fields
@@ -565,7 +616,6 @@ class ValidateSpatial(FieldValidator):
     def __call__(self, data):
         # When we say spatial information, we really mean
         # that it has a three-dimensional data structure
-        # if isinstance(data, FieldDetector): return True
         if not getattr(data, "_spatial", False):
             raise NeedsGridType(self.ghost_zones, self.fields)
         if self.ghost_zones <= data._num_ghost_zones:
@@ -574,11 +624,12 @@ class ValidateSpatial(FieldValidator):
 
 
 class ValidateGridType(FieldValidator):
+    """
+    A :class:`FieldValidator` that ensures the data handed to the field is an actual
+    grid patch, not a covering grid of any kind. Does not accept parameters.
+    """
+
     def __init__(self):
-        """
-        This validator ensures that the data handed to the field is an actual
-        grid patch, not a covering grid of any kind.
-        """
         FieldValidator.__init__(self)
 
     def __call__(self, data):
