@@ -3,17 +3,12 @@ A proxy object for field descriptors, usually living as ds.fields.
 """
 
 import inspect
-import sys
 import textwrap
 import weakref
+from functools import cached_property
 
 from yt.fields.derived_field import DerivedField
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from yt._maintenance.backports import cached_property
-
 
 def _fill_values(values):
     value = (
@@ -21,9 +16,7 @@ def _fill_values(values):
         + "<table><thead><tr><th>Name</th><th>Type</th>"
         + "<th>Value</th></tr></thead><tr><td>"
         + "</td></tr><tr><td>".join(
-            "{}</td><td>{}</td><td>{}".format(
-                v, type(values[v]).__name__, str(values[v])
-            )
+            f"{v}</td><td>{type(values[v]).__name__}</td><td>{str(values[v])}"
             for v in sorted(values)
         )
         + "</td></tr></table></div>"
