@@ -1,15 +1,36 @@
+import sys
+
 import numpy as np
 
+from yt._typing import FieldType
 from yt.fields.derived_field import ValidateParameter
+from yt.fields.field_info_container import FieldInfoContainer
+from yt.geometry.api import Geometry
 from yt.units import dimensions
-from yt.units.yt_array import ustack
-from yt.utilities.math_utils import get_sph_phi_component, get_sph_theta_component
 
 from .field_plugin_registry import register_field_plugin
 
+if sys.version_info >= (3, 11):
+    from typing import assert_never
+else:
+    from typing_extensions import assert_never
+
+cgs_normalizations = {"gaussian": 4.0 * np.pi, "lorentz_heaviside": 1.0}
+
+
+def get_magnetic_normalization(key: str) -> float:
+    if key not in cgs_normalizations:
+        raise ValueError(
+            "Unknown magnetic normalization convention. "
+            f"Got {key!r}, expected one of {tuple(cgs_normalizations)}"
+        )
+    return cgs_normalizations[key]
+
 
 @register_field_plugin
-def setup_magnetic_field_fields(registry, ftype="gas", slice_info=None):
+def setup_magnetic_field_fields(
+    registry: FieldInfoContainer, ftype: FieldType = "gas", slice_info=None
+) -> None:
     ds = registry.ds
 
     unit_system = ds.unit_system
@@ -24,7 +45,7 @@ def setup_magnetic_field_fields(registry, ftype="gas", slice_info=None):
 
     def mag_factors(dims):
         if dims == dimensions.magnetic_field_cgs:
-            return 4.0 * np.pi
+            return getattr(ds, "_magnetic_factor", 4.0 * np.pi)
         elif dims == dimensions.magnetic_field_mks:
             return ds.units.physical_constants.mu_0
 
@@ -56,12 +77,6 @@ def setup_magnetic_field_fields(registry, ftype="gas", slice_info=None):
         units=unit_system["pressure"],
     )
 
-    registry.alias(
-        (ftype, "magnetic_energy"),
-        (ftype, "magnetic_energy_density"),
-        deprecate=("4.0.0", "4.1.0"),
-    )
-
     def _plasma_beta(field, data):
         return data[ftype, "pressure"] / data[ftype, "magnetic_energy_density"]
 
@@ -79,96 +94,129 @@ def setup_magnetic_field_fields(registry, ftype="gas", slice_info=None):
         units=unit_system["pressure"],
     )
 
-    if registry.ds.geometry == "cartesian":
+    _magnetic_field_poloidal_magnitude = None
+    _magnetic_field_toroidal_magnitude = None
 
-        def _magnetic_field_poloidal(field, data):
-            normal = data.get_field_parameter("normal")
+    geometry: Geometry = registry.ds.geometry
 
-            Bfields = ustack(
-                [
-                    data[ftype, "relative_magnetic_field_x"],
-                    data[ftype, "relative_magnetic_field_y"],
-                    data[ftype, "relative_magnetic_field_z"],
-                ]
+    if geometry is Geometry.CARTESIAN:
+
+        def _magnetic_field_poloidal_magnitude(field, data):
+            B2 = (
+                data[ftype, "relative_magnetic_field_x"]
+                * data[ftype, "relative_magnetic_field_x"]
+                + data[ftype, "relative_magnetic_field_y"]
+                * data[ftype, "relative_magnetic_field_y"]
+                + data[ftype, "relative_magnetic_field_z"]
+                * data[ftype, "relative_magnetic_field_z"]
             )
-
-            theta = data["index", "spherical_theta"]
-            phi = data["index", "spherical_phi"]
-
-            return get_sph_theta_component(Bfields, theta, phi, normal)
-
-        def _magnetic_field_toroidal(field, data):
-            normal = data.get_field_parameter("normal")
-
-            Bfields = ustack(
-                [
-                    data[ftype, "relative_magnetic_field_x"],
-                    data[ftype, "relative_magnetic_field_y"],
-                    data[ftype, "relative_magnetic_field_z"],
-                ]
+            Bt2 = (
+                data[ftype, "magnetic_field_spherical_phi"]
+                * data[ftype, "magnetic_field_spherical_phi"]
             )
+            return np.sqrt(B2 - Bt2)
 
-            phi = data["index", "spherical_phi"]
-            return get_sph_phi_component(Bfields, phi, normal)
+    elif geometry is Geometry.CYLINDRICAL or geometry is Geometry.POLAR:
 
-    elif registry.ds.geometry == "cylindrical":
-
-        def _magnetic_field_poloidal(field, data):
+        def _magnetic_field_poloidal_magnitude(field, data):
             bm = data.get_field_parameter("bulk_magnetic_field")
-            r = data["index", "r"]
-            z = data["index", "z"]
-            d = np.sqrt(r * r + z * z)
-            rax = axis_names.find("r")
-            zax = axis_names.find("z")
-            return (data[ftype, "magnetic_field_r"] - bm[rax]) * (r / d) + (
-                data[ftype, "magnetic_field_z"] - bm[zax]
-            ) * (z / d)
+            rax = axis_names.index("r")
+            zax = axis_names.index("z")
 
-        def _magnetic_field_toroidal(field, data):
+            return np.sqrt(
+                (data[ftype, "magnetic_field_r"] - bm[rax]) ** 2
+                + (data[ftype, "magnetic_field_z"] - bm[zax]) ** 2
+            )
+
+        def _magnetic_field_toroidal_magnitude(field, data):
             ax = axis_names.find("theta")
             bm = data.get_field_parameter("bulk_magnetic_field")
             return data[ftype, "magnetic_field_theta"] - bm[ax]
 
-    elif registry.ds.geometry == "spherical":
+    elif geometry is Geometry.SPHERICAL:
 
-        def _magnetic_field_poloidal(field, data):
-            ax = axis_names.find("theta")
+        def _magnetic_field_poloidal_magnitude(field, data):
             bm = data.get_field_parameter("bulk_magnetic_field")
-            return data[ftype, "magnetic_field_theta"] - bm[ax]
+            rax = axis_names.index("r")
+            tax = axis_names.index("theta")
 
-        def _magnetic_field_toroidal(field, data):
+            return np.sqrt(
+                (data[ftype, "magnetic_field_r"] - bm[rax]) ** 2
+                + (data[ftype, "magnetic_field_theta"] - bm[tax]) ** 2
+            )
+
+        def _magnetic_field_toroidal_magnitude(field, data):
             ax = axis_names.find("phi")
             bm = data.get_field_parameter("bulk_magnetic_field")
             return data[ftype, "magnetic_field_phi"] - bm[ax]
 
+    elif geometry is Geometry.GEOGRAPHIC or geometry is Geometry.INTERNAL_GEOGRAPHIC:
+        # not implemented
+        pass
+    elif geometry is Geometry.SPECTRAL_CUBE:
+        # nothing to be done
+        pass
     else:
+        assert_never(geometry)
 
-        # Unidentified geometry--set to None
+    if _magnetic_field_poloidal_magnitude is not None:
+        registry.add_field(
+            (ftype, "magnetic_field_poloidal_magnitude"),
+            sampling_type="local",
+            function=_magnetic_field_poloidal_magnitude,
+            units=u,
+            validators=[
+                ValidateParameter("normal"),
+                ValidateParameter("bulk_magnetic_field"),
+            ],
+        )
 
-        _magnetic_field_toroidal = None
-        _magnetic_field_poloidal = None
+    if _magnetic_field_toroidal_magnitude is not None:
+        registry.add_field(
+            (ftype, "magnetic_field_toroidal_magnitude"),
+            sampling_type="local",
+            function=_magnetic_field_toroidal_magnitude,
+            units=u,
+            validators=[
+                ValidateParameter("normal"),
+                ValidateParameter("bulk_magnetic_field"),
+            ],
+        )
 
-    registry.add_field(
-        (ftype, "magnetic_field_poloidal"),
-        sampling_type="local",
-        function=_magnetic_field_poloidal,
-        units=u,
-        validators=[
-            ValidateParameter("normal"),
-            ValidateParameter("bulk_magnetic_field"),
-        ],
-    )
-
-    registry.add_field(
-        (ftype, "magnetic_field_toroidal"),
-        sampling_type="local",
-        function=_magnetic_field_toroidal,
-        units=u,
-        validators=[
-            ValidateParameter("normal"),
-            ValidateParameter("bulk_magnetic_field"),
-        ],
-    )
+    if geometry is Geometry.CARTESIAN:
+        registry.alias(
+            (ftype, "magnetic_field_toroidal_magnitude"),
+            (ftype, "magnetic_field_spherical_phi"),
+            units=u,
+        )
+        registry.alias(
+            (ftype, "magnetic_field_toroidal"),
+            (ftype, "magnetic_field_spherical_phi"),
+            units=u,
+            deprecate=("4.1.0", None),
+        )
+        registry.alias(
+            (ftype, "magnetic_field_poloidal"),
+            (ftype, "magnetic_field_spherical_theta"),
+            units=u,
+            deprecate=("4.1.0", None),
+        )
+    elif (
+        geometry is Geometry.CYLINDRICAL
+        or geometry is Geometry.POLAR
+        or geometry is Geometry.SPHERICAL
+    ):
+        # These cases should be covered already, just check that they are
+        assert (ftype, "magnetic_field_toroidal_magnitude") in registry
+        assert (ftype, "magnetic_field_poloidal_magnitude") in registry
+    elif geometry is Geometry.GEOGRAPHIC or geometry is Geometry.INTERNAL_GEOGRAPHIC:
+        # not implemented
+        pass
+    elif geometry is Geometry.SPECTRAL_CUBE:
+        # nothing to be done
+        pass
+    else:
+        assert_never(Geometry)
 
     def _alfven_speed(field, data):
         B = data[ftype, "magnetic_field_strength"]
@@ -195,9 +243,9 @@ def setup_magnetic_field_fields(registry, ftype="gas", slice_info=None):
     if dimensions.current_mks in b_units.dimensions.free_symbols:
         rm_scale = pc.qp.to("C", "SI") ** 3 / (4.0 * np.pi * pc.eps_0)
     else:
-        rm_scale = pc.qp ** 3 / pc.clight
+        rm_scale = pc.qp**3 / pc.clight
     rm_scale *= registry.ds.quan(1.0, "rad") / (
-        2.0 * np.pi * pc.me ** 2 * pc.clight ** 3
+        2.0 * np.pi * pc.me**2 * pc.clight**3
     )
     rm_units = registry.ds.quan(1.0, "rad/m**2").units / unit_system["length"]
 
@@ -278,7 +326,7 @@ def setup_magnetic_field_aliases(registry, ds_ftype, ds_fields, ftype="gas"):
     # Add fields
     if sampling_type in ["cell", "local"]:
         # Grid dataset case
-        def mag_field(fd):
+        def mag_field_from_field(fd):
             def _mag_field(field, data):
                 return data[fd].to(field.units)
 
@@ -288,12 +336,12 @@ def setup_magnetic_field_aliases(registry, ds_ftype, ds_fields, ftype="gas"):
             registry.add_field(
                 (ftype, f"magnetic_field_{ax}"),
                 sampling_type=sampling_type,
-                function=mag_field(fd),
+                function=mag_field_from_field(fd),
                 units=units,
             )
     else:
         # Particle dataset case
-        def mag_field(ax):
+        def mag_field_from_ax(ax):
             def _mag_field(field, data):
                 return data[ds_field][:, "xyz".index(ax)]
 
@@ -304,9 +352,9 @@ def setup_magnetic_field_aliases(registry, ds_ftype, ds_fields, ftype="gas"):
             registry.add_field(
                 (ds_ftype, fname),
                 sampling_type=sampling_type,
-                function=mag_field(ax),
+                function=mag_field_from_ax(ax),
                 units=units,
             )
-            sph_ptypes = getattr(registry.ds, "_sph_ptypes", tuple())
+            sph_ptypes = getattr(registry.ds, "_sph_ptypes", ())
             if ds_ftype in sph_ptypes:
                 registry.alias((ftype, f"magnetic_field_{ax}"), (ds_ftype, fname))
