@@ -2,14 +2,13 @@ import glob
 import os
 import struct
 import weakref
-from typing import Type
 
 import numpy as np
 
 import yt.utilities.fortran_utils as fpu
 from yt.data_objects.index_subobjects.octree_subset import OctreeSubset
-from yt.data_objects.particle_unions import ParticleUnion
 from yt.data_objects.static_output import Dataset, ParticleFile
+from yt.data_objects.unions import ParticleUnion
 from yt.frontends.art.definitions import (
     amr_header_struct,
     constants,
@@ -79,7 +78,7 @@ class ARTIndex(OctreeIndex):
         self.oct_handler.finalize()
 
     def _detect_output_fields(self):
-        self.particle_field_list = [f for f in particle_fields]
+        self.particle_field_list = list(particle_fields)
         self.field_list = [("art", f) for f in fluid_fields]
         # now generate all of the possible particle fields
         for ptype in self.dataset.particle_types_raw:
@@ -133,7 +132,7 @@ class ARTIndex(OctreeIndex):
 
 
 class ARTDataset(Dataset):
-    _index_class: Type[Index] = ARTIndex
+    _index_class: type[Index] = ARTIndex
     _field_info_class = ARTFieldInfo
 
     def __init__(
@@ -373,7 +372,7 @@ class ARTDataset(Dataset):
             self.add_particle_union(pu)
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         """
         Defined for the NMSU file naming scheme.
         This could differ for other formats.
@@ -666,7 +665,7 @@ class DarkMatterARTDataset(ARTDataset):
         pass
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         """
         Defined for the NMSU file naming scheme.
         This could differ for other formats.
