@@ -1,8 +1,8 @@
+from numpy.testing import assert_almost_equal, assert_equal
+
 from yt.frontends.art.api import ARTDataset
 from yt.testing import (
     ParticleSelectionComparison,
-    assert_almost_equal,
-    assert_equal,
     requires_file,
     units_override_check,
 )
@@ -57,7 +57,7 @@ def test_d9p_global_values():
     assert_equal(ad[("stars", "particle_type")].size, AnaNStars)
     assert_equal(ad[("specie4", "particle_type")].size, AnaNStars)
 
-    # The *real* asnwer is 2833405, but yt misses one particle since it lives
+    # The *real* answer is 2833405, but yt misses one particle since it lives
     # on a domain boundary. See issue 814. When that is fixed, this test
     # will need to be updated
     AnaNDM = 2833404
