@@ -1,7 +1,7 @@
 import os
 import weakref
 from collections import defaultdict
-from typing import Optional, Tuple
+from typing import Optional
 
 import numpy as np
 
@@ -338,8 +338,8 @@ class ARTIOIndex(Index):
         self,
         icoords: np.ndarray,
         ires: np.ndarray,
-        axes: Optional[Tuple[int, ...]] = None,
-    ) -> Tuple[np.ndarray, np.ndarray]:
+        axes: Optional[tuple[int, ...]] = None,
+    ) -> tuple[np.ndarray, np.ndarray]:
         """
         Accepts icoords and ires and returns appropriate fcoords and fwidth.
         Mostly useful for cases where we have irregularly spaced or structured
@@ -516,7 +516,7 @@ class ARTIODataset(Dataset):
             self.add_particle_union(pu)
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         # a valid artio header file starts with a prefix and ends with .art
         name, _, ext = filename.rpartition(".")
         if ext != "art":
