@@ -99,11 +99,11 @@ def parse_line(line, grid):
         grid["level"] = int(str23(splitup[time_index + 3]).rstrip(","))
         grid["domain"] = int(str23(splitup[time_index + 5]).rstrip(","))
     elif chk23("DIMENSIONS") in splitup:
-        grid["dimensions"] = np.array(str23(splitup[-3:])).astype("int")
+        grid["dimensions"] = np.array(str23(splitup[-3:]), dtype="int")
     elif chk23("ORIGIN") in splitup:
-        grid["left_edge"] = np.array(str23(splitup[-3:])).astype("float64")
+        grid["left_edge"] = np.array(str23(splitup[-3:]), dtype="float64")
     elif chk23("SPACING") in splitup:
-        grid["dds"] = np.array(str23(splitup[-3:])).astype("float64")
+        grid["dds"] = np.array(str23(splitup[-3:]), dtype="float64")
     elif chk23("CELL_DATA") in splitup or chk23("POINT_DATA") in splitup:
         grid["ncells"] = int(str23(splitup[-1]))
     elif chk23("SCALARS") in splitup:
@@ -147,7 +147,7 @@ class AthenaHierarchy(GridIndex):
             chkp = chk23("POINT_DATA")
             if chkd in splitup:
                 field = str23(splitup[-3:])
-                grid_dims = np.array(field).astype("int")
+                grid_dims = np.array(field, dtype="int64")
                 line = check_readline(f)
             elif chkc in splitup or chkp in splitup:
                 grid_ncells = int(str23(splitup[-1]))
@@ -317,7 +317,7 @@ class AthenaHierarchy(GridIndex):
         # know the extent of all the grids.
         glis = np.round(
             (glis - self.dataset.domain_left_edge.ndarray_view()) / gdds
-        ).astype("int")
+        ).astype("int64")
         new_dre = np.max(gres, axis=0)
         dre_units = self.dataset.domain_right_edge.uq
         self.dataset.domain_right_edge = np.round(new_dre, decimals=12) * dre_units
@@ -329,7 +329,7 @@ class AthenaHierarchy(GridIndex):
         )
         self.dataset.domain_dimensions = np.round(
             self.dataset.domain_width / gdds[0]
-        ).astype("int")
+        ).astype("int64")
 
         if self.dataset.dimensionality <= 2:
             self.dataset.domain_dimensions[2] = 1
@@ -382,7 +382,7 @@ class AthenaHierarchy(GridIndex):
             gdds = (self.grid_right_edge - self.grid_left_edge) / self.grid_dimensions
             glis = np.round(
                 (self.grid_left_edge - self.ds.domain_left_edge) / gdds
-            ).astype("int")
+            ).astype("int64")
             for i in range(self.num_grids):
                 self.grids[i] = self.grid(
                     i,
@@ -630,7 +630,7 @@ class AthenaDataset(Dataset):
         )
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".vtk"):
             return False
 
