@@ -1,12 +1,13 @@
 import numpy as np
 
+from yt._typing import KnownFieldsT
 from yt.fields.field_info_container import (
     FieldInfoContainer,
     particle_deposition_functions,
     particle_vector_functions,
     standard_particle_fields,
 )
-from yt.units.unit_object import Unit
+from yt.units.unit_object import Unit  # type: ignore
 from yt.utilities.exceptions import YTFieldNotFound
 
 rho_units = "code_mass / code_length**3"
@@ -16,17 +17,16 @@ vel_units = "code_length / code_time"
 b_units = "code_magnetic"
 
 
-# Chombo does not have any known fields by itself.
 class ChomboFieldInfo(FieldInfoContainer):
-    known_other_fields = ()
-    known_particle_fields = ()
+    # no custom behaviour is needed yet
+    pass
 
 
 # Orion 2 Fields
 # We duplicate everything here from Boxlib, because we want to be able to
 # subclass it and that can be somewhat tricky.
 class Orion2FieldInfo(ChomboFieldInfo):
-    known_other_fields = (
+    known_other_fields: KnownFieldsT = (
         ("density", (rho_units, ["density"], None)),
         ("energy-density", (eden_units, ["total_energy_density"], None)),
         ("radiation-energy-density", (eden_units, ["radiation_energy_density"], None)),
@@ -42,7 +42,7 @@ class Orion2FieldInfo(ChomboFieldInfo):
         ("directrad-dpydt-density", (mom_units, ["directrad-dpydt-density"], None)),
         ("directrad-dpzdt-density", (mom_units, ["directrad-dpzdt-density"], None)),
     )
-    known_particle_fields = (
+    known_particle_fields: KnownFieldsT = (
         ("particle_mass", ("code_mass", [], None)),
         ("particle_position_x", ("code_length", [], None)),
         ("particle_position_y", ("code_length", [], None)),
@@ -195,7 +195,7 @@ class Orion2FieldInfo(ChomboFieldInfo):
 
 
 class ChomboPICFieldInfo3D(FieldInfoContainer):
-    known_other_fields = (
+    known_other_fields: KnownFieldsT = (
         ("density", (rho_units, ["density", "Density"], None)),
         (
             "potential",
@@ -205,7 +205,7 @@ class ChomboPICFieldInfo3D(FieldInfoContainer):
         ("gravitational_field_y", ("code_length / code_time**2", [], None)),
         ("gravitational_field_z", ("code_length / code_time**2", [], None)),
     )
-    known_particle_fields = (
+    known_particle_fields: KnownFieldsT = (
         ("particle_mass", ("code_mass", [], None)),
         ("particle_position_x", ("code_length", [], None)),
         ("particle_position_y", ("code_length", [], None)),
@@ -281,7 +281,7 @@ particle_field_types = ["io", "all"]
 
 
 class ChomboPICFieldInfo2D(ChomboPICFieldInfo3D):
-    known_other_fields = (
+    known_other_fields: KnownFieldsT = (
         ("density", (rho_units, ["density", "Density"], None)),
         (
             "potential",
@@ -290,7 +290,7 @@ class ChomboPICFieldInfo2D(ChomboPICFieldInfo3D):
         ("gravitational_field_x", ("code_length / code_time**2", [], None)),
         ("gravitational_field_y", ("code_length / code_time**2", [], None)),
     )
-    known_particle_fields = (
+    known_particle_fields: KnownFieldsT = (
         ("particle_mass", ("code_mass", [], None)),
         ("particle_position_x", ("code_length", [], None)),
         ("particle_position_y", ("code_length", [], None)),
@@ -326,7 +326,7 @@ class ChomboPICFieldInfo2D(ChomboPICFieldInfo3D):
 
 
 class ChomboPICFieldInfo1D(ChomboPICFieldInfo3D):
-    known_other_fields = (
+    known_other_fields: KnownFieldsT = (
         ("density", (rho_units, ["density", "Density"], None)),
         (
             "potential",
@@ -334,7 +334,7 @@ class ChomboPICFieldInfo1D(ChomboPICFieldInfo3D):
         ),
         ("gravitational_field_x", ("code_length / code_time**2", [], None)),
     )
-    known_particle_fields = (
+    known_particle_fields: KnownFieldsT = (
         ("particle_mass", ("code_mass", [], None)),
         ("particle_position_x", ("code_length", [], None)),
         ("particle_velocity_x", ("code_length / code_time", [], None)),
@@ -386,7 +386,7 @@ class ChomboPICFieldInfo1D(ChomboPICFieldInfo3D):
 
 
 class PlutoFieldInfo(ChomboFieldInfo):
-    known_other_fields = (
+    known_other_fields: KnownFieldsT = (
         ("rho", (rho_units, ["density"], None)),
         ("prs", ("code_mass / (code_length * code_time**2)", ["pressure"], None)),
         ("vx1", (vel_units, ["velocity_x"], None)),
