@@ -55,7 +55,7 @@ class IOHandlerExodusII(BaseIOHandler):
                 ftype, fname = field
                 if ftype == "all":
                     mesh_ids = [mesh.mesh_id + 1 for mesh in self.ds.index.mesh_union]
-                    objs = [mesh for mesh in self.ds.index.mesh_union]
+                    objs = list(self.ds.index.mesh_union)
                 else:
                     mesh_ids = [int(ftype.replace("connect", ""))]
                     chunk = chunks[mesh_ids[0] - 1]
