@@ -5,7 +5,6 @@ import warnings
 import weakref
 from collections import defaultdict
 from functools import cached_property
-from typing import Type
 
 import numpy as np
 import numpy.core.defchararray as np_char
@@ -315,8 +314,9 @@ def check_sky_coords(filename, ndim):
 
 
 class FITSDataset(Dataset):
+    _load_requirements = ["astropy"]
     _index_class = FITSHierarchy
-    _field_info_class: Type[FieldInfoContainer] = FITSFieldInfo
+    _field_info_class: type[FieldInfoContainer] = FITSFieldInfo
     _dataset_type = "fits"
     _handle = None
 
@@ -426,9 +426,16 @@ class FITSDataset(Dataset):
         self.magnetic_unit.convert_to_units("gauss")
         self.velocity_unit = self.length_unit / self.time_unit
 
+    @property
+    def filename(self) -> str:
+        if self._input_filename.startswith("InMemory"):
+            return self._input_filename
+        else:
+            return super().filename
+
     @cached_property
     def unique_identifier(self) -> str:
-        if self.parameter_filename.startswith("InMemory"):
+        if self.filename.startswith("InMemory"):
             return str(time.time())
         else:
             return super().unique_identifier
@@ -453,7 +460,7 @@ class FITSDataset(Dataset):
 
         self.domain_dimensions = np.array(self.dims)[: self.dimensionality]
         if self.dimensionality == 2:
-            self.domain_dimensions = np.append(self.domain_dimensions, [int(1)])
+            self.domain_dimensions = np.append(self.domain_dimensions, [1])
         self._determine_bbox()
 
         # Get the simulation time
@@ -485,7 +492,7 @@ class FITSDataset(Dataset):
         if self.specified_parameters["nprocs"] is None:
             nprocs = np.around(
                 np.prod(self.domain_dimensions) / 32**self.dimensionality
-            ).astype("int")
+            ).astype("int64")
             self.parameters["nprocs"] = max(min(nprocs, 512), 1)
         else:
             self.parameters["nprocs"] = self.specified_parameters["nprocs"]
@@ -533,7 +540,10 @@ class FITSDataset(Dataset):
         self.lon_name = "X"
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
+        if cls._missing_load_requirements():
+            return False
+
         try:
             fileh = check_fits_valid(filename)
         except Exception:
@@ -571,6 +581,7 @@ def find_axes(axis_names, prefixes):
 
 
 class YTFITSDataset(FITSDataset):
+    _load_requirements = ["astropy"]
     _field_info_class = YTFITSFieldInfo
 
     def _parse_parameter_file(self):
@@ -635,7 +646,10 @@ class YTFITSDataset(FITSDataset):
         self.domain_right_edge = domain_right_edge
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
+        if cls._missing_load_requirements():
+            return False
+
         try:
             fileh = check_fits_valid(filename)
         except Exception:
@@ -653,6 +667,7 @@ class YTFITSDataset(FITSDataset):
 
 
 class SkyDataFITSDataset(FITSDataset):
+    _load_requirements = ["astropy"]
     _field_info_class = WCSFITSFieldInfo
 
     def _determine_wcs(self):
@@ -712,7 +727,10 @@ class SkyDataFITSDataset(FITSDataset):
             self.unit_registry.add("beam", beam_size, dimensions=dimensions.solid_angle)
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
+        if cls._missing_load_requirements():
+            return False
+
         try:
             return check_sky_coords(filename, ndim=2)
         except Exception:
@@ -724,7 +742,7 @@ class SpectralCubeFITSHierarchy(FITSHierarchy):
         dz = self.ds.quan(1.0, "code_length") * self.ds.spectral_factor
         self.grid_dimensions[:, 2] = np.around(
             float(self.ds.domain_dimensions[2]) / self.num_grids
-        ).astype("int")
+        ).astype("int64")
         self.grid_dimensions[-1, 2] += self.ds.domain_dimensions[2] % self.num_grids
         self.grid_left_edge[0, 2] = self.ds.domain_left_edge[2]
         self.grid_left_edge[1:, 2] = (
@@ -739,6 +757,7 @@ class SpectralCubeFITSHierarchy(FITSHierarchy):
 
 
 class SpectralCubeFITSDataset(SkyDataFITSDataset):
+    _load_requirements = ["astropy"]
     _index_class = SpectralCubeFITSHierarchy
 
     def __init__(
@@ -800,7 +819,7 @@ class SpectralCubeFITSDataset(SkyDataFITSDataset):
             self.domain_right_edge[self.spec_axis]
             - self.domain_left_edge[self.spec_axis]
         )
-        dre = self.domain_right_edge
+        dre = self.domain_right_edge.copy()
         dre[self.spec_axis] = (
             self.domain_left_edge[self.spec_axis] + self.spectral_factor * Dz
         )
@@ -811,7 +830,7 @@ class SpectralCubeFITSDataset(SkyDataFITSDataset):
     def _determine_nprocs(self):
         # If nprocs is None, do some automatic decomposition of the domain
         if self.specified_parameters["nprocs"] is None:
-            nprocs = np.around(self.domain_dimensions[2] / 8).astype("int")
+            nprocs = np.around(self.domain_dimensions[2] / 8).astype("int64")
             self.parameters["nprocs"] = max(min(nprocs, 512), 1)
         else:
             self.parameters["nprocs"] = self.specified_parameters["nprocs"]
@@ -825,7 +844,10 @@ class SpectralCubeFITSDataset(SkyDataFITSDataset):
         return self.arr((pv.v - self._p0) * self._dz + self._z0, self.spec_unit)
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
+        if cls._missing_load_requirements():
+            return False
+
         try:
             return check_sky_coords(filename, ndim=3)
         except Exception:
@@ -858,6 +880,7 @@ class EventsFITSHierarchy(FITSHierarchy):
 
 
 class EventsFITSDataset(SkyDataFITSDataset):
+    _load_requirements = ["astropy"]
     _index_class = EventsFITSHierarchy
 
     def __init__(
@@ -927,7 +950,10 @@ class EventsFITSDataset(SkyDataFITSDataset):
         self.wcs_2d = self.wcs
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
+        if cls._missing_load_requirements():
+            return False
+
         try:
             fileh = check_fits_valid(filename)
         except Exception:
