@@ -131,6 +131,23 @@ class RAMSESFieldInfo(FieldInfoContainer):
         ("particle_metallicity", ("", [], None)),
         ("particle_family", ("", [], None)),
         ("particle_tag", ("", [], None)),
+        # sink field parameters
+        ("particle_mass", ("code_mass", [], None)),
+        ("particle_angular_momentum_x", (ang_mom_units, [], None)),
+        ("particle_angular_momentum_y", (ang_mom_units, [], None)),
+        ("particle_angular_momentum_z", (ang_mom_units, [], None)),
+        ("particle_formation_time", ("code_time", [], None)),
+        ("particle_accretion_Rate", ("code_mass/code_time", [], None)),
+        ("particle_delta_mass", ("code_mass", [], None)),
+        ("particle_rho_gas", (rho_units, [], None)),
+        ("particle_cs**2", (vel_units, [], None)),
+        ("particle_etherm", (ener_units, [], None)),
+        ("particle_velocity_x_gas", (vel_units, [], None)),
+        ("particle_velocity_y_gas", (vel_units, [], None)),
+        ("particle_velocity_z_gas", (vel_units, [], None)),
+        ("particle_mass_bh", ("code_mass", [], None)),
+        ("particle_level", ("", [], None)),
+        ("particle_radius_star", ("code_length", [], None)),
     )
 
     known_sink_fields: KnownFieldsT = (
@@ -264,7 +281,20 @@ class RAMSESFieldInfo(FieldInfoContainer):
         p = RTFieldFileHandler.get_rt_parameters(self.ds).copy()
         p.update(self.ds.parameters)
         ngroups = p["nGroups"]
-        rt_c = p["rt_c_frac"] * units.c / (p["unit_l"] / p["unit_t"])
+        # Make sure rt_c_frac is at least as long as the number of levels in
+        # the simulation. Pad with either 1 (default) when using level-dependent
+        # reduced speed of light, otherwise pad with a constant value
+        if len(p["rt_c_frac"]) == 1:
+            pad_value = p["rt_c_frac"][0]
+        else:
+            pad_value = 1
+        rt_c_frac = np.pad(
+            p["rt_c_frac"],
+            (0, max(0, self.ds.max_level - len(["rt_c_frac"]) + 1)),
+            constant_values=pad_value,
+        )
+
+        rt_c = rt_c_frac * units.c / (p["unit_l"] / p["unit_t"])
         dens_conv = (p["unit_np"] / rt_c).value / units.cm**3
 
         ########################################
@@ -306,7 +336,10 @@ class RAMSESFieldInfo(FieldInfoContainer):
         # Adding the fields in the rt_ files
         def gen_pdens(igroup):
             def _photon_density(field, data):
-                rv = data["ramses-rt", f"Photon_density_{igroup + 1}"] * dens_conv
+                # The photon density depends on the possibly level-dependent conversion factor.
+                ilvl = data["index", "grid_level"].astype("int64")
+                dc = dens_conv[ilvl]
+                rv = data["ramses-rt", f"Photon_density_{igroup + 1}"] * dc
                 return rv
 
             return _photon_density
@@ -320,6 +353,9 @@ class RAMSESFieldInfo(FieldInfoContainer):
             )
 
         flux_conv = p["unit_pf"] / units.cm**2 / units.s
+        flux_unit = (
+            1 / self.ds.unit_system["time"] / self.ds.unit_system["length"] ** 2
+        ).units
 
         def gen_flux(key, igroup):
             def _photon_flux(field, data):
@@ -328,9 +364,6 @@ class RAMSESFieldInfo(FieldInfoContainer):
 
             return _photon_flux
 
-        flux_unit = (
-            1 / self.ds.unit_system["time"] / self.ds.unit_system["length"] ** 2
-        ).units
         for key in "xyz":
             for igroup in range(ngroups):
                 self.add_field(
@@ -394,15 +427,17 @@ class RAMSESFieldInfo(FieldInfoContainer):
                     )
                     return
                 if var.size == n1 * n2:
-                    tvals[tname] = dict(
-                        data=var.reshape((n1, n2), order="F"), unit=unit
-                    )
+                    tvals[tname] = {
+                        "data": var.reshape((n1, n2), order="F"),
+                        "unit": unit,
+                    }
                 else:
                     var = var.reshape((n1, n2, var.size // (n1 * n2)), order="F")
                     for i in range(var.shape[-1]):
-                        tvals[_cool_species[i]] = dict(
-                            data=var[:, :, i], unit="1/cm**3"
-                        )
+                        tvals[_cool_species[i]] = {
+                            "data": var[:, :, i],
+                            "unit": "1/cm**3",
+                        }
 
         # Add the mu field first, as it is needed for the number density
         interp = BilinearFieldInterpolator(
