@@ -112,11 +112,13 @@ class RockstarDataset(ParticleDataset):
         setdefaultattr(self, "time_unit", self.length_unit / self.velocity_unit)
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".bin"):
             return False
-        with open(filename, mode="rb") as f:
-            header = fpu.read_cattrs(f, header_dt)
-            if header["magic"] == 18077126535843729616:
-                return True
-        return False
+        try:
+            with open(filename, mode="rb") as f:
+                header = fpu.read_cattrs(f, header_dt)
+        except OSError:
+            return False
+        else:
+            return header["magic"] == 18077126535843729616
