@@ -3,7 +3,6 @@ import weakref
 from collections import defaultdict
 from functools import cached_property
 from numbers import Number as numeric_type
-from typing import Tuple, Type
 
 import numpy as np
 
@@ -44,7 +43,7 @@ class SavedDataset(Dataset):
     """
 
     geometry = Geometry.CARTESIAN
-    _con_attrs: Tuple[str, ...] = ()
+    _con_attrs: tuple[str, ...] = ()
 
     def _parse_parameter_file(self):
         self.refine_by = 2
@@ -237,9 +236,10 @@ class YTDataHDF5File(ParticleFile):
 class YTDataContainerDataset(YTDataset):
     """Dataset for saved geometric data containers."""
 
+    _load_requirements = ["h5py"]
     _index_class = ParticleIndex
     _file_class = YTDataHDF5File
-    _field_info_class: Type[FieldInfoContainer] = YTDataContainerFieldInfo
+    _field_info_class: type[FieldInfoContainer] = YTDataContainerFieldInfo
     _suffix = ".h5"
     fluid_types = ("grid", "gas", "deposit", "index")
 
@@ -300,9 +300,13 @@ class YTDataContainerDataset(YTDataset):
         return my_obj(*my_args)
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".h5"):
             return False
+
+        if cls._missing_load_requirements():
+            return False
+
         with h5py.File(filename, mode="r") as f:
             data_type = parse_h5_attr(f, "data_type")
             cont_type = parse_h5_attr(f, "container_type")
@@ -319,6 +323,8 @@ class YTDataContainerDataset(YTDataset):
 class YTDataLightRayDataset(YTDataContainerDataset):
     """Dataset for saved LightRay objects."""
 
+    _load_requirements = ["h5py"]
+
     def _parse_parameter_file(self):
         super()._parse_parameter_file()
         self._restore_light_ray_solution()
@@ -347,9 +353,13 @@ class YTDataLightRayDataset(YTDataContainerDataset):
                 self.light_ray_solution[i][field_name] = self.parameters[field][i]
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".h5"):
             return False
+
+        if cls._missing_load_requirements():
+            return False
+
         with h5py.File(filename, mode="r") as f:
             data_type = parse_h5_attr(f, "data_type")
             if data_type in ["yt_light_ray"]:
@@ -360,6 +370,7 @@ class YTDataLightRayDataset(YTDataContainerDataset):
 class YTSpatialPlotDataset(YTDataContainerDataset):
     """Dataset for saved slices and projections."""
 
+    _load_requirements = ["h5py"]
     _field_info_class = YTGridFieldInfo
 
     def __init__(self, *args, **kwargs):
@@ -377,9 +388,13 @@ class YTSpatialPlotDataset(YTDataContainerDataset):
                 self.parameters["weight_field"] = tuple(self.parameters["weight_field"])
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".h5"):
             return False
+
+        if cls._missing_load_requirements():
+            return False
+
         with h5py.File(filename, mode="r") as f:
             data_type = parse_h5_attr(f, "data_type")
             cont_type = parse_h5_attr(f, "container_type")
@@ -480,12 +495,13 @@ class YTGridHierarchy(YTDataHierarchy):
 class YTGridDataset(YTDataset):
     """Dataset for saved covering grids, arbitrary grids, and FRBs."""
 
-    _index_class: Type[Index] = YTGridHierarchy
+    _load_requirements = ["h5py"]
+    _index_class: type[Index] = YTGridHierarchy
     _field_info_class = YTGridFieldInfo
     _dataset_type = "ytgridhdf5"
     geometry = Geometry.CARTESIAN
     default_fluid_type = "grid"
-    fluid_types: Tuple[str, ...] = ("grid", "gas", "deposit", "index")
+    fluid_types: tuple[str, ...] = ("grid", "gas", "deposit", "index")
 
     def __init__(self, filename, unit_system="cgs"):
         super().__init__(filename, self._dataset_type, unit_system=unit_system)
@@ -514,7 +530,7 @@ class YTGridDataset(YTDataset):
                 )
                 self.domain_dimensions = (
                     (self.domain_right_edge - self.domain_left_edge) / dx
-                ).astype(int)
+                ).astype("int64")
             else:
                 self.domain_right_edge = self.parameters["right_edge"]
                 self.domain_dimensions = self.parameters["ActiveDimensions"]
@@ -551,9 +567,13 @@ class YTGridDataset(YTDataset):
                 self.field_info.alias(("gas", field), ("grid", field))
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".h5"):
             return False
+
+        if cls._missing_load_requirements():
+            return False
+
         with h5py.File(filename, mode="r") as f:
             data_type = parse_h5_attr(f, "data_type")
             cont_type = parse_h5_attr(f, "container_type")
@@ -712,12 +732,13 @@ class YTNonspatialHierarchy(YTDataHierarchy):
 class YTNonspatialDataset(YTGridDataset):
     """Dataset for general array data."""
 
+    _load_requirements = ["h5py"]
     _index_class = YTNonspatialHierarchy
     _field_info_class = YTGridFieldInfo
     _dataset_type = "ytnonspatialhdf5"
     geometry = Geometry.CARTESIAN
     default_fluid_type = "data"
-    fluid_types: Tuple[str, ...] = ("data", "gas")
+    fluid_types: tuple[str, ...] = ("data", "gas")
 
     def _parse_parameter_file(self):
         super(YTGridDataset, self)._parse_parameter_file()
@@ -767,9 +788,13 @@ class YTNonspatialDataset(YTGridDataset):
         mylog.warning("Geometric data selection not available for this dataset type.")
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".h5"):
             return False
+
+        if cls._missing_load_requirements():
+            return False
+
         with h5py.File(filename, mode="r") as f:
             data_type = parse_h5_attr(f, "data_type")
             if data_type == "yt_array_data":
@@ -780,6 +805,7 @@ class YTNonspatialDataset(YTGridDataset):
 class YTProfileDataset(YTNonspatialDataset):
     """Dataset for saved profile objects."""
 
+    _load_requirements = ["h5py"]
     fluid_types = ("data", "gas", "standard_deviation")
 
     def __init__(self, filename, unit_system="cgs"):
@@ -882,9 +908,13 @@ class YTProfileDataset(YTNonspatialDataset):
         super().print_key_parameters()
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".h5"):
             return False
+
+        if cls._missing_load_requirements():
+            return False
+
         with h5py.File(filename, mode="r") as f:
             data_type = parse_h5_attr(f, "data_type")
             if data_type == "yt_profile":
@@ -930,6 +960,8 @@ class YTClumpContainer(TreeContainer):
 class YTClumpTreeDataset(YTNonspatialDataset):
     """Dataset for saved clump-finder data."""
 
+    _load_requirements = ["h5py"]
+
     def __init__(self, filename, unit_system="cgs"):
         super().__init__(filename, unit_system=unit_system)
         self._load_tree()
@@ -957,9 +989,13 @@ class YTClumpTreeDataset(YTNonspatialDataset):
         return [clump for clump in self.tree if clump.children is None]
 
     @classmethod
-    def _is_valid(cls, filename, *args, **kwargs):
+    def _is_valid(cls, filename: str, *args, **kwargs) -> bool:
         if not filename.endswith(".h5"):
             return False
+
+        if cls._missing_load_requirements():
+            return False
+
         with h5py.File(filename, mode="r") as f:
             data_type = parse_h5_attr(f, "data_type")
             if data_type is None:
