@@ -1,10 +1,9 @@
 # Some tests for the Cylindrical coordinates handler
 
 import numpy as np
+from numpy.testing import assert_almost_equal, assert_equal
 
-from yt import SlicePlot
-from yt.testing import add_noise_fields, assert_almost_equal, assert_equal, fake_amr_ds
-from yt.utilities.answer_testing.framework import GenericImageTest
+from yt.testing import fake_amr_ds
 
 # Our canonical tests are that we can access all of our fields and we can
 # compute our volume correctly.
@@ -33,22 +32,3 @@ def test_cylindrical_coordinates():
     assert_equal(
         dd["index", "path_element_theta"], dd["index", "r"] * dd["index", "dtheta"]
     )
-
-
-def test_noise_plots():
-    ds = fake_amr_ds(geometry="cylindrical")
-    add_noise_fields(ds)
-
-    def create_image(filename_prefix):
-        fields = ["noise%d" % i for i in range(4)]
-
-        p = SlicePlot(ds, "z", fields)
-        p.save(f"{filename_prefix}_log")
-
-        p.set_log("all", False)
-        p.save(f"{filename_prefix}_lin")
-
-    test = GenericImageTest(ds, create_image, 12)
-    test.prefix = "test_noise_plot_lin"
-    test_noise_plots.__name__ = test.description
-    yield test
