@@ -1,8 +1,9 @@
 # Some tests for the geographic coordinates handler
 
 import numpy as np
+from numpy.testing import assert_equal
 
-from yt.testing import assert_equal, assert_rel_equal, fake_amr_ds
+from yt.testing import assert_rel_equal, fake_amr_ds
 
 # Our canonical tests are that we can access all of our fields and we can
 # compute our volume correctly.
