@@ -72,7 +72,6 @@ class Tree:
         max_level=None,
         data_source=None,
     ):
-
         self.ds = ds
         try:
             self._id_offset = ds.index.grids[0]._id_offset
@@ -129,7 +128,7 @@ class Tree:
             nre = self.ds.arr(node.get_right_edge(), units="code_length")
             li = np.rint((nle - gle) / dds).astype("int32")
             ri = np.rint((nre - gle) / dds).astype("int32")
-            dims = (ri - li).astype("int32")
+            dims = ri - li
             assert np.all(grid.LeftEdge <= nle)
             assert np.all(grid.RightEdge >= nre)
             assert np.all(dims > 0)
@@ -154,7 +153,7 @@ class Tree:
             nre = self.ds.arr(node.get_right_edge(), units="code_length")
             li = np.rint((nle - gle) / dds).astype("int32")
             ri = np.rint((nre - gle) / dds).astype("int32")
-            dims = (ri - li).astype("int32")
+            dims = ri - li
             cells += np.prod(dims)
         return cells
 
@@ -171,7 +170,6 @@ class AMRKDTree(ParallelAnalysisInterface):
     no_ghost = True
 
     def __init__(self, ds, min_level=None, max_level=None, data_source=None):
-
         if not issubclass(ds.index.__class__, GridIndex):
             raise RuntimeError(
                 "AMRKDTree does not support particle or octree-based data."
@@ -262,7 +260,7 @@ class AMRKDTree(ParallelAnalysisInterface):
             nre = node.get_right_edge()
             li = np.rint((nle - gle) / dds).astype("int32")
             ri = np.rint((nre - gle) / dds).astype("int32")
-            dims = (ri - li).astype("int32")
+            dims = ri - li
             sl = (slice(li[0], ri[0]), slice(li[1], ri[1]), slice(li[2], ri[2]))
             gi = grid.get_global_startindex() + li
             yield grid, node, (sl, dims, gi)
@@ -330,7 +328,7 @@ class AMRKDTree(ParallelAnalysisInterface):
         nre = node.get_right_edge()
         li = np.rint((nle - gle) / dds).astype("int32")
         ri = np.rint((nre - gle) / dds).astype("int32")
-        dims = (ri - li).astype("int32")
+        dims = ri - li
         assert np.all(grid.LeftEdge <= nle)
         assert np.all(grid.RightEdge >= nre)
 
@@ -344,7 +342,7 @@ class AMRKDTree(ParallelAnalysisInterface):
             for i, field in enumerate(self.fields):
                 if self.log_fields[i]:
                     v = vcd[field].astype("float64")
-                    v[v < 0] = np.nan
+                    v[v <= 0] = np.nan
                     dds.append(np.log10(v))
                 else:
                     dds.append(vcd[field].astype("float64"))
@@ -354,9 +352,8 @@ class AMRKDTree(ParallelAnalysisInterface):
         if self.data_source.selector is None:
             mask = np.ones(dims, dtype="uint8")
         else:
-            mask = self.data_source.selector.fill_mask(grid)[
-                li[0] : ri[0], li[1] : ri[1], li[2] : ri[2]
-            ].astype("uint8")
+            mask, _ = self.data_source.selector.fill_mask_regular_grid(grid)
+            mask = mask[li[0] : ri[0], li[1] : ri[1], li[2] : ri[2]].astype("uint8")
 
         data = [
             d[li[0] : ri[0] + 1, li[1] : ri[1] + 1, li[2] : ri[2] + 1].copy()
@@ -372,17 +369,6 @@ class AMRKDTree(ParallelAnalysisInterface):
             self.brick_dimensions.append(dims)
         return brick
 
-    def locate_brick(self, position):
-        """Given a position, find the node that contains it."""
-        from yt._maintenance.deprecation import issue_deprecation_warning
-
-        issue_deprecation_warning(
-            "`AMRKDTree.locate_brick` is a deprecated alias "
-            "for `AMRKDTree.locate_node`.",
-            removal="4.1.0",
-        )
-        return self.locate_node(position)
-
     def locate_neighbors(self, grid, ci):
         r"""Given a grid and cell index, finds the 26 neighbor grids
         and cell indices.
