@@ -1,12 +1,12 @@
 import numpy as np
-
-from yt.testing import (
+from numpy.testing import (
     assert_array_equal,
     assert_array_less,
     assert_equal,
     assert_raises,
-    fake_random_ds,
 )
+
+from yt.testing import fake_random_ds
 from yt.utilities.lib.misc_utilities import (
     obtain_position_vector,
     obtain_relative_velocity_vector,
