@@ -1,4 +1,5 @@
 import os
+from collections import UserDict
 from io import StringIO
 
 import numpy as np
@@ -13,7 +14,7 @@ def get_thingking_deps():
     except ImportError:
         raise ImportError(
             "This functionality requires the thingking package to be installed"
-        )
+        ) from None
     return HTTPArray, PageCacheURL
 
 
@@ -256,8 +257,7 @@ class HTTPDataStruct(DataStruct):
             self.data[k] = RedirectArray(self.handle, k)
 
 
-class SDFRead(dict):
-
+class SDFRead(UserDict):
     _eof = "SDF-EO"
     _data_struct = DataStruct
 
@@ -297,6 +297,7 @@ class SDFRead(dict):
         >>> print(sdf["x"])
 
         """
+        super().__init__()
         self.filename = filename
         if header is None:
             header = filename
@@ -438,7 +439,6 @@ class SDFRead(dict):
 
 
 class HTTPSDFRead(SDFRead):
-
     r"""Read an SDF file hosted on the internet.
 
     Given an SDF file (see https://bitbucket.org/JohnSalmon/sdf), parse the
@@ -616,7 +616,6 @@ class SDFIndex:
         self._max_key = max_key
 
     def _fix_rexact(self, rmin, rmax):
-
         center = 0.5 * (rmax + rmin)
         mysize = rmax - rmin
         mysize *= 1.0 + 4.0 * np.finfo(np.float32).eps
@@ -777,7 +776,7 @@ class SDFIndex:
 
     def get_ibbox_slow(self, ileft, iright):
         """
-        Given left and right indicies, return a mask and
+        Given left and right indices, return a mask and
         set of offsets+lengths into the sdf data.
         """
         mask = np.zeros(self.indexdata["index"].shape, dtype="bool")
@@ -796,7 +795,7 @@ class SDFIndex:
 
     def get_ibbox(self, ileft, iright):
         """
-        Given left and right indicies, return a mask and
+        Given left and right indices, return a mask and
         set of offsets+lengths into the sdf data.
         """
         # print('Getting data from ileft to iright:',  ileft, iright)
@@ -863,7 +862,7 @@ class SDFIndex:
 
     def get_bbox(self, left, right):
         """
-        Given left and right indicies, return a mask and
+        Given left and right indices, return a mask and
         set of offsets+lengths into the sdf data.
         """
         ileft = np.floor((left - self.rmin) / self.domain_width * self.domain_dims)
@@ -1140,7 +1139,6 @@ class SDFIndex:
         return self.iter_data(inds, fields)
 
     def get_contiguous_chunk(self, left_key, right_key, fields):
-
         lbase = 0
         if left_key > self._max_key:
             raise RuntimeError(
