@@ -1,7 +1,7 @@
 import numpy as np
+from numpy.testing import assert_almost_equal, assert_array_equal
 
 import yt.utilities.decompose as dec
-from yt.testing import assert_almost_equal, assert_array_equal
 
 
 def setup():
