@@ -1,10 +1,8 @@
-import warnings
-
 import numpy as np
+from numpy.testing import assert_array_almost_equal, assert_array_equal
 
 import yt.utilities.linear_interpolators as lin
-from yt._maintenance.deprecation import VisibleDeprecationWarning
-from yt.testing import assert_array_almost_equal, assert_array_equal, fake_random_ds
+from yt.testing import fake_random_ds
 from yt.utilities.lib.interpolators import ghost_zone_interpolate
 
 
@@ -32,7 +30,7 @@ def test_linear_interpolator_1d():
 def test_linear_interpolator_2d():
     random_data = np.random.random((64, 64))
     # evenly spaced bins
-    fv = {ax: v for ax, v in zip("xyz", np.mgrid[0.0:1.0:64j, 0.0:1.0:64j])}
+    fv = dict(zip("xyz", np.mgrid[0.0:1.0:64j, 0.0:1.0:64j]))
     bfi = lin.BilinearFieldInterpolator(random_data, (0.0, 1.0, 0.0, 1.0), "xy", True)
     assert_array_equal(bfi(fv), random_data)
 
@@ -51,9 +49,7 @@ def test_linear_interpolator_2d():
 def test_linear_interpolator_3d():
     random_data = np.random.random((64, 64, 64))
     # evenly spaced bins
-    fv = {
-        ax: v for ax, v in zip("xyz", np.mgrid[0.0:1.0:64j, 0.0:1.0:64j, 0.0:1.0:64j])
-    }
+    fv = dict(zip("xyz", np.mgrid[0.0:1.0:64j, 0.0:1.0:64j, 0.0:1.0:64j]))
     tfi = lin.TrilinearFieldInterpolator(
         random_data, (0.0, 1.0, 0.0, 1.0, 0.0, 1.0), "xyz", True
     )
@@ -75,6 +71,37 @@ def test_linear_interpolator_3d():
     assert_array_almost_equal(tfi(fv), random_data, 15)
 
 
+def test_linear_interpolator_4d():
+    random_data = np.random.random((64, 64, 64, 64))
+    # evenly spaced bins
+    fv = dict(zip("xyzw", np.mgrid[0.0:1.0:64j, 0.0:1.0:64j, 0.0:1.0:64j, 0.0:1.0:64j]))
+    tfi = lin.QuadrilinearFieldInterpolator(
+        random_data, (0.0, 1.0, 0.0, 1.0, 0.0, 1.0, 0.0, 1.0), "xyzw", True
+    )
+    assert_array_almost_equal(tfi(fv), random_data)
+
+    # randomly spaced bins
+    size = 64
+    bins = np.linspace(0.0, 1.0, size)
+    shifts = {ax: (1.0 / size) * np.random.random(size) - (0.5 / size) for ax in "xyzw"}
+    fv["x"] += shifts["x"][:, np.newaxis, np.newaxis, np.newaxis]
+    fv["y"] += shifts["y"][:, np.newaxis, np.newaxis]
+    fv["z"] += shifts["z"][:, np.newaxis]
+    fv["w"] += shifts["w"]
+    tfi = lin.QuadrilinearFieldInterpolator(
+        random_data,
+        (
+            bins + shifts["x"],
+            bins + shifts["y"],
+            bins + shifts["z"],
+            bins + shifts["w"],
+        ),
+        "xyzw",
+        True,
+    )
+    assert_array_almost_equal(tfi(fv), random_data, 15)
+
+
 def test_ghost_zone_extrapolation():
     ds = fake_random_ds(16)
 
@@ -124,22 +151,4 @@ def test_ghost_zone_extrapolation():
 def test_get_vertex_centered_data():
     ds = fake_random_ds(16)
     g = ds.index.grids[0]
-
-    vec_list = g.get_vertex_centered_data([("gas", "density")], no_ghost=True)
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter("always")
-        vec_str = g.get_vertex_centered_data(("gas", "density"), no_ghost=True)
-        assert len(w) == 1
-        assert issubclass(w[-1].category, VisibleDeprecationWarning)
-        assert "requires list of fields" in str(w[-1].message)
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter("always")
-        vec_tuple = g.get_vertex_centered_data(("gas", "density"), no_ghost=True)
-        assert len(w) == 1
-        assert issubclass(w[-1].category, VisibleDeprecationWarning)
-        assert (
-            "get_vertex_centered_data() requires list of fields, rather than "
-            "a single field as an argument."
-        ) in str(w[-1].message)
-    assert_array_equal(vec_list[("gas", "density")], vec_str)
-    assert_array_equal(vec_list[("gas", "density")], vec_tuple)
+    g.get_vertex_centered_data([("gas", "density")], no_ghost=True)
