@@ -2,28 +2,47 @@ import sys
 import warnings
 from abc import ABC
 from io import BytesIO
-from typing import TYPE_CHECKING, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Optional, TypedDict, Union
 
 import matplotlib
 import numpy as np
-from matplotlib.colors import LogNorm, Normalize, SymLogNorm
+from matplotlib.scale import SymmetricalLogTransform
 from matplotlib.ticker import LogFormatterMathtext
-from packaging.version import Version
 
-from yt.funcs import get_interactivity, is_sequence, matplotlib_style_context, mylog
+from yt._typing import AlphaT
+from yt.funcs import (
+    get_interactivity,
+    is_sequence,
+    matplotlib_style_context,
+    mylog,
+    setdefault_mpl_metadata,
+    setdefaultattr,
+)
 from yt.visualization._handlers import ColorbarHandler, NormHandler
 
 from ._commons import (
-    MPL_VERSION,
     get_canvas,
-    get_symlog_majorticks,
-    get_symlog_minorticks,
     validate_image_name,
 )
 
+if matplotlib.__version_info__ >= (3, 8):
+    from matplotlib.ticker import SymmetricalLogLocator
+else:
+    from ._commons import _MPL38_SymmetricalLogLocator as SymmetricalLogLocator
+
 if TYPE_CHECKING:
+    from typing import Literal
+
+    from matplotlib.axes import Axes
     from matplotlib.axis import Axis
     from matplotlib.figure import Figure
+    from matplotlib.transforms import Transform
+
+    class FormatKwargs(TypedDict):
+        style: Literal["scientific"]
+        scilimits: tuple[int, int]
+        useMathText: bool
+
 
 BACKEND_SPECS = {
     "GTK": ["backend_gtk", "FigureCanvasGTK", "FigureManagerGTK"],
@@ -90,11 +109,11 @@ class PlotMPL:
     def __init__(
         self,
         fsize,
-        axrect,
+        axrect: tuple[float, float, float, float],
         *,
         norm_handler: NormHandler,
         figure: Optional["Figure"] = None,
-        axes: Optional["Axis"] = None,
+        axes: Optional["Axes"] = None,
     ):
         """Initialize PlotMPL class"""
         import matplotlib.figure
@@ -110,7 +129,7 @@ class PlotMPL:
         if axes is None:
             self._create_axes(axrect)
         else:
-            axes.cla()
+            axes.clear()
             axes.set_position(axrect)
             self.axes = axes
         self.interactivity = get_interactivity()
@@ -126,7 +145,7 @@ class PlotMPL:
 
         self.norm_handler = norm_handler
 
-    def _create_axes(self, axrect):
+    def _create_axes(self, axrect: tuple[float, float, float, float]) -> None:
         self.axes = self.figure.add_axes(axrect)
 
     def _get_canvas_classes(self):
@@ -160,10 +179,9 @@ class PlotMPL:
 
         if mpl_kwargs is None:
             mpl_kwargs = {}
-        if "papertype" not in mpl_kwargs and MPL_VERSION < Version("3.3.0"):
-            mpl_kwargs["papertype"] = "auto"
 
         name = validate_image_name(name)
+        setdefault_mpl_metadata(mpl_kwargs, name)
 
         try:
             canvas = get_canvas(self.figure, name)
@@ -202,7 +220,7 @@ class PlotMPL:
                 label.set_color(font_color)
 
     def _repr_png_(self):
-        from ._mpl_imports import FigureCanvasAgg
+        from matplotlib.backends.backend_agg import FigureCanvasAgg
 
         canvas = FigureCanvasAgg(self.figure)
         f = BytesIO()
@@ -226,10 +244,14 @@ class ImagePlotMPL(PlotMPL, ABC):
         norm_handler: NormHandler,
         colorbar_handler: ColorbarHandler,
         figure: Optional["Figure"] = None,
-        axes: Optional["Axis"] = None,
-        cax: Optional["Axis"] = None,
+        axes: Optional["Axes"] = None,
+        cax: Optional["Axes"] = None,
     ):
         """Initialize ImagePlotMPL class object"""
+
+        self._transform: Optional["Transform"]
+        setdefaultattr(self, "_transform", None)
+
         self.colorbar_handler = colorbar_handler
         _missing_layout_specs = [_ is None for _ in (fsize, axrect, caxrect)]
 
@@ -247,12 +269,12 @@ class ImagePlotMPL(PlotMPL, ABC):
         if cax is None:
             self.cax = self.figure.add_axes(caxrect)
         else:
-            cax.cla()
+            cax.clear()
             cax.set_position(caxrect)
             self.cax = cax
 
     def _setup_layout_constraints(
-        self, figure_size: Union[Tuple[float, float], float], fontsize: float
+        self, figure_size: Union[tuple[float, float], float], fontsize: float
     ):
         # Setup base layout attributes
         # derived classes need to call this before super().__init__
@@ -282,7 +304,7 @@ class ImagePlotMPL(PlotMPL, ABC):
         self.cax.set_position(caxrect)
         self.figure.set_size_inches(*size)
 
-    def _init_image(self, data, extent, aspect):
+    def _init_image(self, data, extent, aspect, *, alpha: AlphaT = None):
         """Store output of imshow in image variable"""
 
         norm = self.norm_handler.get_norm(data)
@@ -307,69 +329,55 @@ class ImagePlotMPL(PlotMPL, ABC):
             cmap=self.colorbar_handler.cmap,
             interpolation="nearest",
             transform=transform,
+            alpha=alpha,
         )
-        self._set_axes(norm)
+        self._set_axes()
 
-    def _set_axes(self, norm: Normalize) -> None:
-        if isinstance(norm, SymLogNorm):
-            formatter = LogFormatterMathtext(linthresh=norm.linthresh)
-            self.cb = self.figure.colorbar(self.image, self.cax, format=formatter)
-            self.cb.set_ticks(
-                get_symlog_majorticks(
-                    linthresh=norm.linthresh, vmin=norm.vmin, vmax=norm.vmax
-                )
-            )
-        else:
-            self.cb = self.figure.colorbar(self.image, self.cax)
-        self.cax.tick_params(which="both", axis="y", direction="in")
-
-        fmt_kwargs = {"style": "scientific", "scilimits": (-2, 3), "useMathText": True}
+    def _set_axes(self) -> None:
+        fmt_kwargs: "FormatKwargs" = {
+            "style": "scientific",
+            "scilimits": (-2, 3),
+            "useMathText": True,
+        }
         self.image.axes.ticklabel_format(**fmt_kwargs)
-        if type(norm) not in (LogNorm, SymLogNorm):
-            try:
-                self.cb.ax.ticklabel_format(**fmt_kwargs)
-            except AttributeError as exc:
-                if MPL_VERSION < Version("3.5.0"):
-                    warnings.warn(
-                        "Failed to format colorbar ticks. "
-                        "This is expected when using the set_norm method "
-                        "with some matplotlib classes (e.g. TwoSlopeNorm) "
-                        "with matplotlib versions older than 3.5\n"
-                        "Please try upgrading matplotlib to a more recent version. "
-                        "If the problem persists, please file a report to "
-                        "https://github.com/yt-project/yt/issues/new",
-                        stacklevel=2,
-                    )
-                else:
-                    raise exc
-        if self.colorbar_handler.draw_minorticks:
-            if isinstance(norm, SymLogNorm):
-                if MPL_VERSION < Version("3.5.0b"):
-                    # no known working method to draw symlog minor ticks
-                    # see https://github.com/yt-project/yt/issues/3535
-                    pass
-                else:
-                    flinthresh = 10 ** np.floor(np.log10(norm.linthresh))
-                    absmax = np.abs((norm.vmin, norm.vmax)).max()
-                    if (absmax - flinthresh) / absmax < 0.1:
-                        flinthresh /= 10
-                    mticks = get_symlog_minorticks(flinthresh, norm.vmin, norm.vmax)
-                    if MPL_VERSION < Version("3.5.0b"):
-                        # https://github.com/matplotlib/matplotlib/issues/21258
-                        mticks = self.image.norm(mticks)
-                    self.cax.yaxis.set_ticks(mticks, minor=True)
-
-            elif isinstance(norm, LogNorm):
-                self.cax.minorticks_on()
-                self.cax.xaxis.set_visible(False)
-
-            else:
-                self.cax.minorticks_on()
-        else:
-            self.cax.minorticks_off()
-
         self.image.axes.set_facecolor(self.colorbar_handler.background_color)
 
+        self.cax.tick_params(which="both", direction="in")
+        self.cb = self.figure.colorbar(self.image, self.cax)
+
+        cb_axis: "Axis"
+        if self.cb.orientation == "vertical":
+            cb_axis = self.cb.ax.yaxis
+        else:
+            cb_axis = self.cb.ax.xaxis
+
+        cb_scale = cb_axis.get_scale()
+        if cb_scale == "symlog":
+            trf = cb_axis.get_transform()
+            if not isinstance(trf, SymmetricalLogTransform):
+                raise RuntimeError
+            cb_axis.set_major_locator(SymmetricalLogLocator(trf))
+            cb_axis.set_major_formatter(
+                LogFormatterMathtext(linthresh=trf.linthresh, base=trf.base)
+            )
+
+        if cb_scale not in ("log", "symlog"):
+            self.cb.ax.ticklabel_format(**fmt_kwargs)
+
+        if self.colorbar_handler.draw_minorticks and cb_scale == "symlog":
+            # no minor ticks are drawn by default in symlog, as of matplotlib 3.7.1
+            # see https://github.com/matplotlib/matplotlib/issues/25994
+            trf = cb_axis.get_transform()
+            if not isinstance(trf, SymmetricalLogTransform):
+                raise RuntimeError
+            if float(trf.base).is_integer():
+                locator = SymmetricalLogLocator(trf, subs=list(range(1, int(trf.base))))
+                cb_axis.set_minor_locator(locator)
+        elif self.colorbar_handler.draw_minorticks:
+            self.cb.minorticks_on()
+        else:
+            self.cb.minorticks_off()
+
     def _validate_axes_extent(self, extent, transform):
         # if the axes are cartopy GeoAxes, this checks that the axes extent
         # is properly set.
@@ -593,6 +601,7 @@ def get_multi_plot(nx, ny, colorbar="vertical", bw=4, dpi=300, cbar_padding=0.4)
     complicated or more specific sets of multiplots for your own purposes.
     """
     import matplotlib.figure
+    from matplotlib.backends.backend_agg import FigureCanvasAgg
 
     hf, wf = 1.0 / ny, 1.0 / nx
     fudge_x = fudge_y = 1.0
@@ -605,7 +614,6 @@ def get_multi_plot(nx, ny, colorbar="vertical", bw=4, dpi=300, cbar_padding=0.4)
         fudge_x = 1.0
         fudge_y = ny / (cbar_padding + ny)
     fig = matplotlib.figure.Figure((bw * nx / fudge_x, bw * ny / fudge_y), dpi=dpi)
-    from ._mpl_imports import FigureCanvasAgg
 
     fig.set_canvas(FigureCanvasAgg(fig))
     fig.subplots_adjust(
