@@ -1,54 +1,25 @@
-from copy import deepcopy
-from typing import Tuple, Union
+from typing import Union
 
 import cmyt  # noqa: F401
+import matplotlib as mpl
 import numpy as np
-from matplotlib import cm as mcm, colors as cc
-from matplotlib.pyplot import get_cmap
-from packaging.version import Version
+from matplotlib.colors import LinearSegmentedColormap
 
 from yt.funcs import get_brewer_cmap
 from yt.utilities.logger import ytLogger as mylog
 
 from . import _colormap_data as _cm
-from ._commons import MPL_VERSION
 
 yt_colormaps = {}
 
 
-def is_colormap(cmap):
-    return isinstance(cmap, cc.Colormap)
-
-
-def check_color(name):
-    try:
-        cc.colorConverter.to_rgb(name)
-        return True
-    except ValueError:
-        return False
-
-
-def add_cmap(name, cdict):
-    """Deprecated alias, kept for backwards compatibility."""
-    from yt._maintenance.deprecation import issue_deprecation_warning
-
-    issue_deprecation_warning(
-        "`add_cmap` is a deprecated alias for `add_colormap`",
-        since="4.0.0",
-        removal="4.1.0",
-    )
-    add_colormap(name, cdict)
-
-
 def add_colormap(name, cdict):
     """
     Adds a colormap to the colormaps available in yt for this session
     """
     # Note: this function modifies the global variable 'yt_colormaps'
-    yt_colormaps[name] = cc.LinearSegmentedColormap(name, cdict, 256)
-    mcm.datad[name] = cdict
-    mcm.__dict__[name] = cdict
-    mcm.register_cmap(name, yt_colormaps[name])
+    yt_colormaps[name] = LinearSegmentedColormap(name, cdict, 256)
+    mpl.colormaps.register(yt_colormaps[name])
 
 
 # YTEP-0040 backward compatibility layer
@@ -75,21 +46,13 @@ def register_yt_colormaps_from_cmyt():
     For backwards compatibility, register yt colormaps without the "cmyt."
     prefix, but do it in a collision-safe way.
     """
-    from matplotlib.pyplot import get_cmap
 
     for hist_name, alias in _HISTORICAL_ALIASES.items():
-        if MPL_VERSION >= Version("3.4.0"):
-            cmap = get_cmap(alias).copy()
-        else:
-            cmap = deepcopy(get_cmap(alias))
+        # note that mpl.colormaps.__getitem__ returns *copies*
+        cmap = mpl.colormaps[alias]
         cmap.name = hist_name
-        try:
-            mcm.register_cmap(cmap=cmap)
-            mcm.register_cmap(cmap=get_cmap(hist_name).reversed())
-        except ValueError:
-            # Matplotlib 3.4.0 hard-forbids name collisions, but more recent versions
-            # will emit a warning instead, so we emulate this behaviour regardless.
-            mylog.warning("cannot register colormap '%s' (naming collision)", hist_name)
+        mpl.colormaps.register(cmap)
+        mpl.colormaps.register(cmap.reversed())
 
 
 register_yt_colormaps_from_cmyt()
@@ -111,19 +74,19 @@ for k, v in list(_cm.color_map_luts.items()):
         mylog.warning("cannot register colormap '%s' (naming collision)", k)
 
 
-def get_colormap_lut(cmap_id: Union[Tuple[str, str], str]):
+def get_colormap_lut(cmap_id: Union[tuple[str, str], str]):
     # "lut" stands for "lookup table". This function provides a consistent and
-    # reusable accessor to a hidden (and by defaut, uninitialized) attribute
+    # reusable accessor to a hidden (and by default, uninitialized) attribute
     # (`_lut`) in registered colormaps, from matplotlib or palettable.
     # colormap "lookup tables" are RGBA arrays in matplotlib,
-    # and contain sufficient data to reconstruct the colormaps entierly.
+    # and contain sufficient data to reconstruct the colormaps entirely.
     # This exists mostly for historical reasons, hence the custom output format.
     # It isn't meant as part of yt's public api.
 
     if isinstance(cmap_id, tuple) and len(cmap_id) == 2:
         cmap = get_brewer_cmap(cmap_id)
     elif isinstance(cmap_id, str):
-        cmap = get_cmap(cmap_id)
+        cmap = mpl.colormaps[cmap_id]
     else:
         raise TypeError(
             "Expected a string or a 2-tuple of strings as a colormap id. "
@@ -201,29 +164,6 @@ def show_colormaps(subset="all", filename=None):
                 "to be 'all', 'yt_native', or a list of "
                 "valid colormap names."
             ) from e
-    if Version("2.0.0") <= MPL_VERSION < Version("2.2.0"):
-        # the reason we do this filtering is to avoid spurious warnings in CI when
-        # testing against old versions of matplotlib (currently not older than 2.0.x)
-        # and we can't easily filter warnings at the level of the relevant test itself
-        # because it's not yet run exclusively with pytest.
-        # FUTURE: remove this completely when only matplotlib 2.2+ is supported
-        deprecated_cmaps = {
-            "spectral",
-            "spectral_r",
-            "Vega10",
-            "Vega10_r",
-            "Vega20",
-            "Vega20_r",
-            "Vega20b",
-            "Vega20b_r",
-            "Vega20c",
-            "Vega20c_r",
-        }
-        for cmap in deprecated_cmaps:
-            try:
-                maps.remove(cmap)
-            except ValueError:
-                pass
 
     maps = sorted(set(maps))
     # scale the image size by the number of cmaps
@@ -233,7 +173,7 @@ def show_colormaps(subset="all", filename=None):
     for i, m in enumerate(maps):
         plt.subplot(1, l, i + 1)
         plt.axis("off")
-        plt.imshow(a, aspect="auto", cmap=plt.get_cmap(m), origin="lower")
+        plt.imshow(a, aspect="auto", cmap=mpl.colormaps[m], origin="lower")
         plt.title(m, rotation=90, fontsize=10, verticalalignment="bottom")
     if filename is not None:
         plt.savefig(filename, dpi=100, facecolor="gray")
