@@ -36,7 +36,7 @@ def scale_image(image, mi=None, ma=None):
         mi = image.min()
     if ma is None:
         ma = image.max()
-    image = (np.clip((image - mi) / (ma - mi) * 255, 0, 255)).astype("uint8")
+    image = np.clip((image - mi) / (ma - mi) * 255, 0, 255).astype("uint8")
     return image
 
 
@@ -149,6 +149,9 @@ def write_bitmap(bitmap_array, filename, max_val=None, transpose=False):
             alpha_channel.shape = s1, s2, 1
         if max_val is None:
             max_val = bitmap_array[:, :, :3].max()
+            if max_val == 0.0:
+                # avoid dividing by zero for blank images
+                max_val = 1.0
         bitmap_array = np.clip(bitmap_array[:, :, :3] / max_val, 0.0, 1.0) * 255
         bitmap_array = np.concatenate(
             [bitmap_array.astype("uint8"), alpha_channel], axis=-1
@@ -268,52 +271,6 @@ def map_to_colors(buff, cmap_name):
     return mapped.copy("C")
 
 
-def strip_colormap_data(
-    fn="color_map_data.py",
-    cmaps=(
-        "jet",
-        "cmyt.algae",
-        "hot",
-        "gist_stern",
-        "RdBu",
-        "cmyt.pastel",
-        "cmyt.kelp",
-        "cmyt.arbre",
-        "cmyt.octarine",
-        "cmyt.dusk",
-    ),
-):
-    import pprint
-
-    from yt._maintenance.deprecation import issue_deprecation_warning
-
-    from . import color_maps as rcm
-
-    issue_deprecation_warning(
-        "yt.visualization.image_writer.strip_colormap_data is deprecated.",
-        since="4.1.0",
-        removal="4.2.0",
-    )
-    f = open(fn, "w")
-    f.write("### Auto-generated colormap tables, taken from Matplotlib ###\n\n")
-    f.write("from numpy import array\n")
-    f.write("color_map_luts = {}\n\n\n")
-    if cmaps is None:
-        cmaps = rcm.ColorMaps
-    if isinstance(cmaps, str):
-        cmaps = [cmaps]
-    for cmap_name in sorted(cmaps):
-        vals = get_colormap_lut(cmap_name)
-        f.write(f"### {cmap_name} ###\n\n")
-        f.write(f"color_map_luts['{cmap_name}'] = \\\n")
-        f.write("   (\n")
-        for v in vals:
-            f.write(pprint.pformat(v, indent=3))
-            f.write(",\n")
-        f.write("   )\n\n")
-    f.close()
-
-
 def splat_points(image, points_x, points_y, contribution=None, transposed=False):
     if contribution is None:
         contribution = 100.0
