@@ -2,19 +2,17 @@ import abc
 import base64
 import builtins
 import os
-import sys
 import warnings
 from collections import defaultdict
 from functools import wraps
-from typing import Any, Dict, List, Optional, Tuple, Type, Union
+from typing import Any, Final, Literal, Optional, Union
 
 import matplotlib
 from matplotlib.colors import LogNorm, Normalize, SymLogNorm
-from matplotlib.font_manager import FontProperties
 from unyt.dimensions import length
 
 from yt._maintenance.deprecation import issue_deprecation_warning
-from yt._typing import Quantity
+from yt._typing import FieldKey, Quantity
 from yt.config import ytcfg
 from yt.data_objects.time_series import DatasetSeries
 from yt.funcs import ensure_dir, is_sequence, iter_fields
@@ -26,7 +24,8 @@ from yt.visualization._handlers import ColorbarHandler, NormHandler
 from yt.visualization.base_plot_types import PlotMPL
 
 from ._commons import (
-    DEFAULT_FONT_PROPERTIES,
+    _get_units_label,
+    get_default_font_properties,
     invalidate_data,
     invalidate_figure,
     invalidate_plot,
@@ -34,11 +33,6 @@ from ._commons import (
     validate_plot,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Final, Literal
-else:
-    from typing_extensions import Final, Literal
-
 latex_prefixes = {
     "u": r"\mu",
 }
@@ -49,6 +43,7 @@ def apply_callback(f):
         "The apply_callback decorator is not used in yt any more and "
         "will be removed in a future version. "
         "Please do not use it.",
+        stacklevel=3,
         since="4.1",
     )
 
@@ -66,6 +61,7 @@ def accepts_all_fields(func):
     field == 'all', looping over all fields already present in the PlotContainer object.
 
     """
+
     # This is to be applied to PlotContainer class methods with the following signature:
     #
     # f(self, field, *args, **kwargs) -> self
@@ -117,7 +113,7 @@ class PlotDictionary(defaultdict):
 class PlotContainer(abc.ABC):
     """A container for generic plots"""
 
-    _plot_dict_type: Type[PlotDictionary] = PlotDictionary
+    _plot_dict_type: type[PlotDictionary] = PlotDictionary
     _plot_type: Optional[str] = None
     _plot_valid = False
 
@@ -125,6 +121,8 @@ class PlotContainer(abc.ABC):
     _default_font_size = 14.0
 
     def __init__(self, data_source, figure_size=None, fontsize: Optional[float] = None):
+        from matplotlib.font_manager import FontProperties
+
         self.data_source = data_source
         self.ds = data_source.ds
         self.ts = self._initialize_dataset(self.ds)
@@ -134,16 +132,13 @@ class PlotContainer(abc.ABC):
 
         if fontsize is None:
             fontsize = self.__class__._default_font_size
-        if sys.version_info >= (3, 9):
-            font_dict = DEFAULT_FONT_PROPERTIES | {"size": fontsize}
-        else:
-            font_dict = {**DEFAULT_FONT_PROPERTIES, "size": fontsize}  # type:ignore
+        font_dict = get_default_font_properties() | {"size": fontsize}
 
         self._font_properties = FontProperties(**font_dict)
         self._font_color = None
         self._xlabel = None
         self._ylabel = None
-        self._minorticks: Dict[Tuple[str, str], bool] = {}
+        self._minorticks: dict[FieldKey, bool] = {}
 
     @accepts_all_fields
     @invalidate_plot
@@ -244,6 +239,7 @@ class PlotContainer(abc.ABC):
         issue_deprecation_warning(
             "The get_log method is not reliable and is deprecated. "
             "Please do not rely on it.",
+            stacklevel=3,
             since="4.1",
         )
         log = {}
@@ -334,8 +330,9 @@ class PlotContainer(abc.ABC):
           customizations other than plot callbacks (`annotate_*`)
         - testing
         """
-        # this is a pure alias to the historic `_setup_plots` method
-        # which preserves backward compatibility for extension code
+        # this public API method should never be no-op, so we invalidate
+        # the plot to force a fresh render in _setup_plots()
+        self._plot_valid = False
         self._setup_plots()
 
     def _initialize_dataset(self, ts):
@@ -448,6 +445,7 @@ class PlotContainer(abc.ABC):
         ... )
 
         """
+        from matplotlib.font_manager import FontProperties
 
         if font_dict is None:
             font_dict = {}
@@ -455,10 +453,8 @@ class PlotContainer(abc.ABC):
             self._font_color = font_dict.pop("color")
         # Set default values if the user does not explicitly set them.
         # this prevents reverting to the matplotlib defaults.
-        if sys.version_info >= (3, 9):
-            font_dict = DEFAULT_FONT_PROPERTIES | font_dict
-        else:
-            font_dict = {**DEFAULT_FONT_PROPERTIES, **font_dict}
+        _default_size = {"size": self.__class__._default_font_size}
+        font_dict = get_default_font_properties() | _default_size | font_dict
         self._font_properties = FontProperties(**font_dict)
         return self
 
@@ -505,9 +501,9 @@ class PlotContainer(abc.ABC):
     @validate_plot
     def save(
         self,
-        name: Optional[Union[str, List[str], Tuple[str, ...]]] = None,
+        name: Optional[Union[str, list[str], tuple[str, ...]]] = None,
         suffix: Optional[str] = None,
-        mpl_kwargs: Optional[Dict[str, Any]] = None,
+        mpl_kwargs: Optional[dict[str, Any]] = None,
     ):
         """saves the plot to disk.
 
@@ -535,7 +531,8 @@ class PlotContainer(abc.ABC):
             if new_suffix != suffix:
                 warnings.warn(
                     f"Overriding suffix {suffix!r} with mpl_kwargs['format'] = {new_suffix!r}. "
-                    "Use the `suffix` argument directly to suppress this warning."
+                    "Use the `suffix` argument directly to suppress this warning.",
+                    stacklevel=2,
                 )
             suffix = new_suffix
 
@@ -625,7 +622,7 @@ class PlotContainer(abc.ABC):
         Examples
         --------
 
-        >>> from yt.mods import SlicePlot
+        >>> from yt import SlicePlot
         >>> slc = SlicePlot(
         ...     ds, "x", [("gas", "density"), ("gas", "velocity_magnitude")]
         ... )
@@ -662,7 +659,7 @@ class PlotContainer(abc.ABC):
             img = base64.b64encode(self.plots[field]._repr_png_()).decode()
             ret += (
                 r'<img style="max-width:100%;max-height:100%;" '
-                r'src="data:image/png;base64,{}"><br>'.format(img)
+                rf'src="data:image/png;base64,{img}"><br>'
             )
         return ret
 
@@ -720,7 +717,7 @@ class PlotContainer(abc.ABC):
                 axes_unit_labels[i] = ""
                 continue
             if unn is not None:
-                axes_unit_labels[i] = r"\ \ \left(" + unn + r"\right)"
+                axes_unit_labels[i] = _get_units_label(unn).strip("$")
                 continue
             # Use sympy to factor h out of the unit.  In this context 'un'
             # is a string, so we call the Unit constructor.
@@ -757,10 +754,7 @@ class PlotContainer(abc.ABC):
                         symbol_wo_prefix = un[1:]
                         if symbol_wo_prefix in self.ds.unit_registry.prefixable_units:
                             un = un.replace(pp, "{" + latex_prefixes[pp] + "}", 1)
-                if r"\frac" in un:
-                    axes_unit_labels[i] = r"\ \ \left(" + un + r"\right)"
-                else:
-                    axes_unit_labels[i] = r"\ \ (" + un + r")"
+                axes_unit_labels[i] = _get_units_label(un).strip("$")
         return axes_unit_labels
 
     def hide_colorbar(self, field=None):
@@ -901,8 +895,7 @@ class ImagePlotContainer(PlotContainer, abc.ABC):
 
     def _get_default_handlers(
         self, field, default_display_units: Unit
-    ) -> Tuple[NormHandler, ColorbarHandler]:
-
+    ) -> tuple[NormHandler, ColorbarHandler]:
         usr_units_str = get_default_from_config(
             self.data_source, field=field, keys="units", defaults=[None]
         )
@@ -1028,7 +1021,7 @@ class ImagePlotContainer(PlotContainer, abc.ABC):
                 "If you wish to explicitly set zmin to the minimal "
                 "data value, pass `zmin='min'` instead. "
                 "Otherwise leave this argument unset.",
-                since="4.1.0",
+                since="4.1",
                 stacklevel=5,
             )
             zmin = "min"
@@ -1042,7 +1035,7 @@ class ImagePlotContainer(PlotContainer, abc.ABC):
                 "If you wish to explicitly set zmax to the maximal "
                 "data value, pass `zmin='max'` instead. "
                 "Otherwise leave this argument unset.",
-                since="4.1.0",
+                since="4.1",
                 stacklevel=5,
             )
             zmax = "max"
@@ -1099,7 +1092,6 @@ class ImagePlotContainer(PlotContainer, abc.ABC):
 
 
 class BaseLinePlot(PlotContainer, abc.ABC):
-
     # A common ancestor to LinePlot and ProfilePlot
 
     @abc.abstractmethod
@@ -1111,8 +1103,10 @@ class BaseLinePlot(PlotContainer, abc.ABC):
             return self.plots[field]
         axrect = self._get_axrect()
 
-        pnh = NormHandler(self.data_source, display_units=self.data_source[field].units)
-        finfo = self.data_source.ds._get_field_info(*field)
+        pnh = NormHandler(
+            self.data_source, display_units=self.data_source.ds.field_info[field].units
+        )
+        finfo = self.data_source.ds._get_field_info(field)
         if not finfo.take_log:
             pnh.norm_type = Normalize
         plot = PlotMPL(self.figure_size, axrect, norm_handler=pnh)
