@@ -1,8 +1,9 @@
 import base64
 import builtins
 import os
+from collections.abc import Iterable
 from functools import wraps
-from typing import Any, Dict, Iterable, Optional, Tuple, Union
+from typing import Any, Optional, Union
 
 import matplotlib
 import numpy as np
@@ -270,7 +271,7 @@ class ProfilePlot(BaseLinePlot):
         self,
         name: Optional[str] = None,
         suffix: Optional[str] = None,
-        mpl_kwargs: Optional[Dict[str, Any]] = None,
+        mpl_kwargs: Optional[dict[str, Any]] = None,
     ):
         r"""
         Saves a 1d profile plot.
@@ -291,7 +292,7 @@ class ProfilePlot(BaseLinePlot):
         # Mypy is hardly convinced that we have a `profiles` attribute
         # at this stage, so we're lasily going to deactivate it locally
         unique = set(self.plots.values())
-        iters: Iterable[Tuple[Union[int, FieldKey], PlotMPL]]
+        iters: Iterable[tuple[Union[int, FieldKey], PlotMPL]]
         if len(unique) < len(self.plots):
             iters = enumerate(sorted(unique))
         else:
@@ -363,7 +364,7 @@ class ProfilePlot(BaseLinePlot):
             img = base64.b64encode(img).decode()
             ret += (
                 r'<img style="max-width:100%;max-height:100%;" '
-                r'src="data:image/png;base64,{}"><br>'.format(img)
+                rf'src="data:image/png;base64,{img}"><br>'
             )
         return ret
 
@@ -1055,6 +1056,10 @@ class PhasePlot(ImagePlotContainer):
                     fig = self.plots[f].figure
                     axes = self.plots[f].axes
                     cax = self.plots[f].cax
+                else:
+                    fig = None
+                    axes = None
+                    cax = None
             else:
                 pnh, cbh = self._get_default_handlers(
                     field=f, default_display_units=self.profile[f].units
@@ -1555,6 +1560,6 @@ class PhasePlotMPL(ImagePlotMPL):
             shading=self._shading,
         )
 
-        self._set_axes(norm)
+        self._set_axes()
         self.axes.set_xscale(x_scale)
         self.axes.set_yscale(y_scale)
