@@ -3,12 +3,12 @@ import os.path
 import shutil
 import tempfile
 
+import matplotlib as mpl
 import numpy as np
 from numpy.testing import assert_equal
 
 import yt
 from yt.utilities.lib.api import add_rgba_points_to_image  # type: ignore
-from yt.visualization.color_maps import _get_cmap
 
 
 def setup():
@@ -31,7 +31,7 @@ def test_splat():
     xs = prng.random_sample(Np)
     ys = prng.random_sample(Np)
 
-    cbx = _get_cmap("RdBu")
+    cbx = mpl.colormaps["RdBu"]
     cs = cbx(prng.random_sample(Np))
     add_rgba_points_to_image(image, xs, ys, cs)
 
