@@ -1,7 +1,7 @@
 import builtins
 import functools
 from collections import OrderedDict
-from typing import List, Optional
+from typing import Optional, Union
 
 import numpy as np
 
@@ -249,7 +249,6 @@ class Scene:
         return [s for s in self.sources.values() if isinstance(s, RenderSource)]
 
     def _setup_save(self, fname, render) -> str:
-
         self._render_on_demand(render)
 
         rensources = self._get_render_sources()
@@ -346,7 +345,7 @@ class Scene:
             fig = Figure((shape[0] / 100.0, shape[1] / 100.0))
             canvas = get_canvas(fig, fname)
 
-            ax = fig.add_axes([0, 0, 1, 1])
+            ax = fig.add_axes((0, 0, 1, 1))
             ax.set_axis_off()
             out = self._last_render
             if sigma_clip is not None:
@@ -369,7 +368,9 @@ class Scene:
         dpi: int = 100,
         sigma_clip: Optional[float] = None,
         render: bool = True,
-        tf_rect: Optional[List[float]] = None,
+        tf_rect: Optional[list[float]] = None,
+        *,
+        label_fontsize: Union[float, str] = 10,
     ):
         r"""Saves the most recently rendered image of the Scene to disk,
         including an image of the transfer function and and user-defined
@@ -400,6 +401,10 @@ class Scene:
         label_fmt : str, optional
            A format specifier (e.g., label_fmt="%.2g") to use in formatting
            the data values that label the transfer function colorbar.
+        label_fontsize : float or string, optional
+           The fontsize used to display the numbers on the transfer function
+           colorbar.  This can be any matplotlib font size specification, e.g.,
+           "large" or 12. (default: 10)
         text_annotate : list of iterables
            Any text that you wish to display on the image.  This should be an
            list containing a tuple of coordinates (in normalized figure
@@ -461,7 +466,14 @@ class Scene:
             rs = self._get_render_sources()[0]
             tf = rs.transfer_function
             label = rs.data_source.ds._get_field_info(rs.field).get_label()
-            self._annotate(ax.axes, tf, rs, label=label, label_fmt=label_fmt)
+            self._annotate(
+                ax.axes,
+                tf,
+                rs,
+                label=label,
+                label_fmt=label_fmt,
+                label_fontsize=label_fontsize,
+            )
         else:
             # set the origin and width and height of the colorbar region
             if tf_rect is None:
@@ -480,7 +492,14 @@ class Scene:
                     pass
                 else:
                     label = rs.data_source.ds._get_field_info(rs.field).get_label()
-                    self._annotate_multi(ax, tf, rs, label=label, label_fmt=label_fmt)
+                    self._annotate_multi(
+                        ax,
+                        tf,
+                        rs,
+                        label=label,
+                        label_fmt=label_fmt,
+                        label_fontsize=label_fontsize,
+                    )
 
         # any text?
         if text_annotate is not None:
@@ -491,7 +510,7 @@ class Scene:
                 if len(t) == 3:
                     opt = t[2]
                 else:
-                    opt = dict()
+                    opt = {}
 
                 # sane default
                 if "color" not in opt:
@@ -522,7 +541,7 @@ class Scene:
 
         return axim
 
-    def _annotate(self, ax, tf, source, label="", label_fmt=None):
+    def _annotate(self, ax, tf, source, label="", label_fmt=None, label_fontsize=10):
         ax.get_xaxis().set_visible(False)
         ax.get_xaxis().set_ticks([])
         ax.get_yaxis().set_visible(False)
@@ -534,17 +553,19 @@ class Scene:
             ax=cb.ax,
             label=label,
             label_fmt=label_fmt,
+            label_fontsize=label_fontsize,
             resolution=self.camera.resolution[0],
             log_scale=source.log_field,
         )
 
-    def _annotate_multi(self, ax, tf, source, label, label_fmt):
+    def _annotate_multi(self, ax, tf, source, label, label_fmt, label_fontsize=10):
         ax.yaxis.set_label_position("right")
         ax.yaxis.tick_right()
         tf.vert_cbar(
             ax=ax,
             label=label,
             label_fmt=label_fmt,
+            label_fontsize=label_fontsize,
             resolution=self.camera.resolution[0],
             log_scale=source.log_field,
             size=6,
@@ -830,7 +851,7 @@ class Scene:
                 source.annotate_mesh_lines(color=color, alpha=alpha)
         return self
 
-    def annotate_axes(self, colors=None, alpha=1.0):
+    def annotate_axes(self, colors=None, alpha=1.0, *, thickness=1):
         r"""
 
         Modifies this scene by drawing the coordinate axes.
@@ -846,6 +867,8 @@ class Scene:
             ``alpha`` is ignored.
         alpha : float, optional
             The opacity of the vectors.
+        thickness : int, optional
+            The line thickness
 
         Examples
         --------
@@ -858,7 +881,7 @@ class Scene:
         >>> im = sc.render()
 
         """
-        coords = CoordinateVectorSource(colors, alpha)
+        coords = CoordinateVectorSource(colors, alpha, thickness=thickness)
         self.add_source(coords)
         return self
 
