@@ -74,8 +74,9 @@ class ZBuffer:
 
 
 if __name__ == "__main__":
-    shape = (64, 64)
-    for shape in [(64, 64), (16, 16, 4), (128), (16, 32)]:
+    shape: tuple[int, ...] = (64, 64)
+    shapes: list[tuple[int, ...]] = [(64, 64), (16, 16, 4), (128,), (16, 32)]
+    for shape in shapes:
         b1 = ZBuffer(np.random.random(shape), np.ones(shape))
         b2 = ZBuffer(np.random.random(shape), np.zeros(shape))
         c = b1 + b2
